// mkerrors.sh -Wall -Werror -static -I/tmp/include -m32
// Code generated by the command above; see README.md. DO NOT EDIT.

// +build 386,linux

// Code generated by cmd/cgo -godefs; DO NOT EDIT.
// cgo -godefs -- -Wall -Werror -static -I/tmp/include -m32 _const.go

package unix

import "syscall"

const (
	AAFS_MAGIC                           = 0x5a3c69f0
	ADFS_SUPER_MAGIC                     = 0xadf5
	AFFS_SUPER_MAGIC                     = 0xadff
	AFS_FS_MAGIC                         = 0x6b414653
	AFS_SUPER_MAGIC                      = 0x5346414f
	AF_ALG                               = 0x26
	AF_APPLETALK                         = 0x5
	AF_ASH                               = 0x12
	AF_ATMPVC                            = 0x8
	AF_ATMSVC                            = 0x14
	AF_AX25                              = 0x3
	AF_BLUETOOTH                         = 0x1f
	AF_BRIDGE                            = 0x7
	AF_CAIF                              = 0x25
	AF_CAN                               = 0x1d
	AF_DECnet                            = 0xc
	AF_ECONET                            = 0x13
	AF_FILE                              = 0x1
	AF_IB                                = 0x1b
	AF_IEEE802154                        = 0x24
	AF_INET                              = 0x2
	AF_INET6                             = 0xa
	AF_IPX                               = 0x4
	AF_IRDA                              = 0x17
	AF_ISDN                              = 0x22
	AF_IUCV                              = 0x20
	AF_KCM                               = 0x29
	AF_KEY                               = 0xf
	AF_LLC                               = 0x1a
	AF_LOCAL                             = 0x1
	AF_MAX                               = 0x2d
	AF_MPLS                              = 0x1c
	AF_NETBEUI                           = 0xd
	AF_NETLINK                           = 0x10
	AF_NETROM                            = 0x6
	AF_NFC                               = 0x27
	AF_PACKET                            = 0x11
	AF_PHONET                            = 0x23
	AF_PPPOX                             = 0x18
	AF_QIPCRTR                           = 0x2a
	AF_RDS                               = 0x15
	AF_ROSE                              = 0xb
	AF_ROUTE                             = 0x10
	AF_RXRPC                             = 0x21
	AF_SECURITY                          = 0xe
	AF_SMC                               = 0x2b
	AF_SNA                               = 0x16
	AF_TIPC                              = 0x1e
	AF_UNIX                              = 0x1
	AF_UNSPEC                            = 0x0
	AF_VSOCK                             = 0x28
	AF_WANPIPE                           = 0x19
	AF_X25                               = 0x9
	AF_XDP                               = 0x2c
	ALG_OP_DECRYPT                       = 0x0
	ALG_OP_ENCRYPT                       = 0x1
	ALG_SET_AEAD_ASSOCLEN                = 0x4
	ALG_SET_AEAD_AUTHSIZE                = 0x5
	ALG_SET_IV                           = 0x2
	ALG_SET_KEY                          = 0x1
	ALG_SET_OP                           = 0x3
	ANON_INODE_FS_MAGIC                  = 0x9041934
	ARPHRD_6LOWPAN                       = 0x339
	ARPHRD_ADAPT                         = 0x108
	ARPHRD_APPLETLK                      = 0x8
	ARPHRD_ARCNET                        = 0x7
	ARPHRD_ASH                           = 0x30d
	ARPHRD_ATM                           = 0x13
	ARPHRD_AX25                          = 0x3
	ARPHRD_BIF                           = 0x307
	ARPHRD_CAIF                          = 0x336
	ARPHRD_CAN                           = 0x118
	ARPHRD_CHAOS                         = 0x5
	ARPHRD_CISCO                         = 0x201
	ARPHRD_CSLIP                         = 0x101
	ARPHRD_CSLIP6                        = 0x103
	ARPHRD_DDCMP                         = 0x205
	ARPHRD_DLCI                          = 0xf
	ARPHRD_ECONET                        = 0x30e
	ARPHRD_EETHER                        = 0x2
	ARPHRD_ETHER                         = 0x1
	ARPHRD_EUI64                         = 0x1b
	ARPHRD_FCAL                          = 0x311
	ARPHRD_FCFABRIC                      = 0x313
	ARPHRD_FCPL                          = 0x312
	ARPHRD_FCPP                          = 0x310
	ARPHRD_FDDI                          = 0x306
	ARPHRD_FRAD                          = 0x302
	ARPHRD_HDLC                          = 0x201
	ARPHRD_HIPPI                         = 0x30c
	ARPHRD_HWX25                         = 0x110
	ARPHRD_IEEE1394                      = 0x18
	ARPHRD_IEEE802                       = 0x6
	ARPHRD_IEEE80211                     = 0x321
	ARPHRD_IEEE80211_PRISM               = 0x322
	ARPHRD_IEEE80211_RADIOTAP            = 0x323
	ARPHRD_IEEE802154                    = 0x324
	ARPHRD_IEEE802154_MONITOR            = 0x325
	ARPHRD_IEEE802_TR                    = 0x320
	ARPHRD_INFINIBAND                    = 0x20
	ARPHRD_IP6GRE                        = 0x337
	ARPHRD_IPDDP                         = 0x309
	ARPHRD_IPGRE                         = 0x30a
	ARPHRD_IRDA                          = 0x30f
	ARPHRD_LAPB                          = 0x204
	ARPHRD_LOCALTLK                      = 0x305
	ARPHRD_LOOPBACK                      = 0x304
	ARPHRD_METRICOM                      = 0x17
	ARPHRD_NETLINK                       = 0x338
	ARPHRD_NETROM                        = 0x0
	ARPHRD_NONE                          = 0xfffe
	ARPHRD_PHONET                        = 0x334
	ARPHRD_PHONET_PIPE                   = 0x335
	ARPHRD_PIMREG                        = 0x30b
	ARPHRD_PPP                           = 0x200
	ARPHRD_PRONET                        = 0x4
	ARPHRD_RAWHDLC                       = 0x206
	ARPHRD_RAWIP                         = 0x207
	ARPHRD_ROSE                          = 0x10e
	ARPHRD_RSRVD                         = 0x104
	ARPHRD_SIT                           = 0x308
	ARPHRD_SKIP                          = 0x303
	ARPHRD_SLIP                          = 0x100
	ARPHRD_SLIP6                         = 0x102
	ARPHRD_TUNNEL                        = 0x300
	ARPHRD_TUNNEL6                       = 0x301
	ARPHRD_VOID                          = 0xffff
	ARPHRD_VSOCKMON                      = 0x33a
	ARPHRD_X25                           = 0x10f
	AUTOFS_SUPER_MAGIC                   = 0x187
	B0                                   = 0x0
	B1000000                             = 0x1008
	B110                                 = 0x3
	B115200                              = 0x1002
	B1152000                             = 0x1009
	B1200                                = 0x9
	B134                                 = 0x4
	B150                                 = 0x5
	B1500000                             = 0x100a
	B1800                                = 0xa
	B19200                               = 0xe
	B200                                 = 0x6
	B2000000                             = 0x100b
	B230400                              = 0x1003
	B2400                                = 0xb
	B2500000                             = 0x100c
	B300                                 = 0x7
	B3000000                             = 0x100d
	B3500000                             = 0x100e
	B38400                               = 0xf
	B4000000                             = 0x100f
	B460800                              = 0x1004
	B4800                                = 0xc
	B50                                  = 0x1
	B500000                              = 0x1005
	B57600                               = 0x1001
	B576000                              = 0x1006
	B600                                 = 0x8
	B75                                  = 0x2
	B921600                              = 0x1007
	B9600                                = 0xd
	BALLOON_KVM_MAGIC                    = 0x13661366
	BDEVFS_MAGIC                         = 0x62646576
	BINDERFS_SUPER_MAGIC                 = 0x6c6f6f70
	BINFMTFS_MAGIC                       = 0x42494e4d
	BLKBSZGET                            = 0x80041270
	BLKBSZSET                            = 0x40041271
	BLKFLSBUF                            = 0x1261
	BLKFRAGET                            = 0x1265
	BLKFRASET                            = 0x1264
	BLKGETSIZE                           = 0x1260
	BLKGETSIZE64                         = 0x80041272
	BLKPBSZGET                           = 0x127b
	BLKRAGET                             = 0x1263
	BLKRASET                             = 0x1262
	BLKROGET                             = 0x125e
	BLKROSET                             = 0x125d
	BLKRRPART                            = 0x125f
	BLKSECTGET                           = 0x1267
	BLKSECTSET                           = 0x1266
	BLKSSZGET                            = 0x1268
	BOTHER                               = 0x1000
	BPF_A                                = 0x10
	BPF_ABS                              = 0x20
	BPF_ADD                              = 0x0
	BPF_ADJ_ROOM_ENCAP_L2_MASK           = 0xff
	BPF_ADJ_ROOM_ENCAP_L2_SHIFT          = 0x38
	BPF_ALU                              = 0x4
	BPF_ALU64                            = 0x7
	BPF_AND                              = 0x50
	BPF_ANY                              = 0x0
	BPF_ARSH                             = 0xc0
	BPF_B                                = 0x10
	BPF_BUILD_ID_SIZE                    = 0x14
	BPF_CALL                             = 0x80
	BPF_DEVCG_ACC_MKNOD                  = 0x1
	BPF_DEVCG_ACC_READ                   = 0x2
	BPF_DEVCG_ACC_WRITE                  = 0x4
	BPF_DEVCG_DEV_BLOCK                  = 0x1
	BPF_DEVCG_DEV_CHAR                   = 0x2
	BPF_DIV                              = 0x30
	BPF_DW                               = 0x18
	BPF_END                              = 0xd0
	BPF_EXIST                            = 0x2
	BPF_EXIT                             = 0x90
	BPF_FROM_BE                          = 0x8
	BPF_FROM_LE                          = 0x0
	BPF_FS_MAGIC                         = 0xcafe4a11
	BPF_F_ADJ_ROOM_ENCAP_L3_IPV4         = 0x2
	BPF_F_ADJ_ROOM_ENCAP_L3_IPV6         = 0x4
	BPF_F_ADJ_ROOM_ENCAP_L4_GRE          = 0x8
	BPF_F_ADJ_ROOM_ENCAP_L4_UDP          = 0x10
	BPF_F_ADJ_ROOM_FIXED_GSO             = 0x1
	BPF_F_ALLOW_MULTI                    = 0x2
	BPF_F_ALLOW_OVERRIDE                 = 0x1
	BPF_F_ANY_ALIGNMENT                  = 0x2
	BPF_F_CTXLEN_MASK                    = 0xfffff00000000
	BPF_F_CURRENT_CPU                    = 0xffffffff
	BPF_F_CURRENT_NETNS                  = -0x1
	BPF_F_DONT_FRAGMENT                  = 0x4
	BPF_F_FAST_STACK_CMP                 = 0x200
	BPF_F_HDR_FIELD_MASK                 = 0xf
	BPF_F_INDEX_MASK                     = 0xffffffff
	BPF_F_INGRESS                        = 0x1
	BPF_F_INVALIDATE_HASH                = 0x2
	BPF_F_LOCK                           = 0x4
	BPF_F_MARK_ENFORCE                   = 0x40
	BPF_F_MARK_MANGLED_0                 = 0x20
	BPF_F_NO_COMMON_LRU                  = 0x2
	BPF_F_NO_PREALLOC                    = 0x1
	BPF_F_NUMA_NODE                      = 0x4
	BPF_F_PSEUDO_HDR                     = 0x10
	BPF_F_QUERY_EFFECTIVE                = 0x1
	BPF_F_RDONLY                         = 0x8
	BPF_F_RDONLY_PROG                    = 0x80
	BPF_F_RECOMPUTE_CSUM                 = 0x1
	BPF_F_REUSE_STACKID                  = 0x400
	BPF_F_SEQ_NUMBER                     = 0x8
	BPF_F_SKIP_FIELD_MASK                = 0xff
	BPF_F_STACK_BUILD_ID                 = 0x20
	BPF_F_STRICT_ALIGNMENT               = 0x1
	BPF_F_SYSCTL_BASE_NAME               = 0x1
	BPF_F_TEST_RND_HI32                  = 0x4
	BPF_F_TUNINFO_IPV6                   = 0x1
	BPF_F_USER_BUILD_ID                  = 0x800
	BPF_F_USER_STACK                     = 0x100
	BPF_F_WRONLY                         = 0x10
	BPF_F_WRONLY_PROG                    = 0x100
	BPF_F_ZERO_CSUM_TX                   = 0x2
	BPF_F_ZERO_SEED                      = 0x40
	BPF_H                                = 0x8
	BPF_IMM                              = 0x0
	BPF_IND                              = 0x40
	BPF_JA                               = 0x0
	BPF_JEQ                              = 0x10
	BPF_JGE                              = 0x30
	BPF_JGT                              = 0x20
	BPF_JLE                              = 0xb0
	BPF_JLT                              = 0xa0
	BPF_JMP                              = 0x5
	BPF_JMP32                            = 0x6
	BPF_JNE                              = 0x50
	BPF_JSET                             = 0x40
	BPF_JSGE                             = 0x70
	BPF_JSGT                             = 0x60
	BPF_JSLE                             = 0xd0
	BPF_JSLT                             = 0xc0
	BPF_K                                = 0x0
	BPF_LD                               = 0x0
	BPF_LDX                              = 0x1
	BPF_LEN                              = 0x80
	BPF_LL_OFF                           = -0x200000
	BPF_LSH                              = 0x60
	BPF_MAJOR_VERSION                    = 0x1
	BPF_MAXINSNS                         = 0x1000
	BPF_MEM                              = 0x60
	BPF_MEMWORDS                         = 0x10
	BPF_MINOR_VERSION                    = 0x1
	BPF_MISC                             = 0x7
	BPF_MOD                              = 0x90
	BPF_MOV                              = 0xb0
	BPF_MSH                              = 0xa0
	BPF_MUL                              = 0x20
	BPF_NEG                              = 0x80
	BPF_NET_OFF                          = -0x100000
	BPF_NOEXIST                          = 0x1
	BPF_OBJ_NAME_LEN                     = 0x10
	BPF_OR                               = 0x40
	BPF_PSEUDO_CALL                      = 0x1
	BPF_PSEUDO_MAP_FD                    = 0x1
	BPF_PSEUDO_MAP_VALUE                 = 0x2
	BPF_RET                              = 0x6
	BPF_RSH                              = 0x70
	BPF_SK_STORAGE_GET_F_CREATE          = 0x1
	BPF_SOCK_OPS_ALL_CB_FLAGS            = 0xf
	BPF_SOCK_OPS_RETRANS_CB_FLAG         = 0x2
	BPF_SOCK_OPS_RTO_CB_FLAG             = 0x1
	BPF_SOCK_OPS_RTT_CB_FLAG             = 0x8
	BPF_SOCK_OPS_STATE_CB_FLAG           = 0x4
	BPF_ST                               = 0x2
	BPF_STX                              = 0x3
	BPF_SUB                              = 0x10
	BPF_TAG_SIZE                         = 0x8
	BPF_TAX                              = 0x0
	BPF_TO_BE                            = 0x8
	BPF_TO_LE                            = 0x0
	BPF_TXA                              = 0x80
	BPF_W                                = 0x0
	BPF_X                                = 0x8
	BPF_XADD                             = 0xc0
	BPF_XOR                              = 0xa0
	BRKINT                               = 0x2
	BS0                                  = 0x0
	BS1                                  = 0x2000
	BSDLY                                = 0x2000
	BTRFS_SUPER_MAGIC                    = 0x9123683e
	BTRFS_TEST_MAGIC                     = 0x73727279
	CAN_BCM                              = 0x2
	CAN_EFF_FLAG                         = 0x80000000
	CAN_EFF_ID_BITS                      = 0x1d
	CAN_EFF_MASK                         = 0x1fffffff
	CAN_ERR_FLAG                         = 0x20000000
	CAN_ERR_MASK                         = 0x1fffffff
	CAN_INV_FILTER                       = 0x20000000
	CAN_ISOTP                            = 0x6
	CAN_MAX_DLC                          = 0x8
	CAN_MAX_DLEN                         = 0x8
	CAN_MCNET                            = 0x5
	CAN_MTU                              = 0x10
	CAN_NPROTO                           = 0x7
	CAN_RAW                              = 0x1
	CAN_RAW_FILTER_MAX                   = 0x200
	CAN_RTR_FLAG                         = 0x40000000
	CAN_SFF_ID_BITS                      = 0xb
	CAN_SFF_MASK                         = 0x7ff
	CAN_TP16                             = 0x3
	CAN_TP20                             = 0x4
	CAP_AUDIT_CONTROL                    = 0x1e
	CAP_AUDIT_READ                       = 0x25
	CAP_AUDIT_WRITE                      = 0x1d
	CAP_BLOCK_SUSPEND                    = 0x24
	CAP_CHOWN                            = 0x0
	CAP_DAC_OVERRIDE                     = 0x1
	CAP_DAC_READ_SEARCH                  = 0x2
	CAP_FOWNER                           = 0x3
	CAP_FSETID                           = 0x4
	CAP_IPC_LOCK                         = 0xe
	CAP_IPC_OWNER                        = 0xf
	CAP_KILL                             = 0x5
	CAP_LAST_CAP                         = 0x25
	CAP_LEASE                            = 0x1c
	CAP_LINUX_IMMUTABLE                  = 0x9
	CAP_MAC_ADMIN                        = 0x21
	CAP_MAC_OVERRIDE                     = 0x20
	CAP_MKNOD                            = 0x1b
	CAP_NET_ADMIN                        = 0xc
	CAP_NET_BIND_SERVICE                 = 0xa
	CAP_NET_BROADCAST                    = 0xb
	CAP_NET_RAW                          = 0xd
	CAP_SETFCAP                          = 0x1f
	CAP_SETGID                           = 0x6
	CAP_SETPCAP                          = 0x8
	CAP_SETUID                           = 0x7
	CAP_SYSLOG                           = 0x22
	CAP_SYS_ADMIN                        = 0x15
	CAP_SYS_BOOT                         = 0x16
	CAP_SYS_CHROOT                       = 0x12
	CAP_SYS_MODULE                       = 0x10
	CAP_SYS_NICE                         = 0x17
	CAP_SYS_PACCT                        = 0x14
	CAP_SYS_PTRACE                       = 0x13
	CAP_SYS_RAWIO                        = 0x11
	CAP_SYS_RESOURCE                     = 0x18
	CAP_SYS_TIME                         = 0x19
	CAP_SYS_TTY_CONFIG                   = 0x1a
	CAP_WAKE_ALARM                       = 0x23
	CBAUD                                = 0x100f
	CBAUDEX                              = 0x1000
	CFLUSH                               = 0xf
	CGROUP2_SUPER_MAGIC                  = 0x63677270
	CGROUP_SUPER_MAGIC                   = 0x27e0eb
	CIBAUD                               = 0x100f0000
	CLOCAL                               = 0x800
	CLOCK_BOOTTIME                       = 0x7
	CLOCK_BOOTTIME_ALARM                 = 0x9
	CLOCK_DEFAULT                        = 0x0
	CLOCK_EXT                            = 0x1
	CLOCK_INT                            = 0x2
	CLOCK_MONOTONIC                      = 0x1
	CLOCK_MONOTONIC_COARSE               = 0x6
	CLOCK_MONOTONIC_RAW                  = 0x4
	CLOCK_PROCESS_CPUTIME_ID             = 0x2
	CLOCK_REALTIME                       = 0x0
	CLOCK_REALTIME_ALARM                 = 0x8
	CLOCK_REALTIME_COARSE                = 0x5
	CLOCK_TAI                            = 0xb
	CLOCK_THREAD_CPUTIME_ID              = 0x3
	CLOCK_TXFROMRX                       = 0x4
	CLOCK_TXINT                          = 0x3
	CLONE_CHILD_CLEARTID                 = 0x200000
	CLONE_CHILD_SETTID                   = 0x1000000
	CLONE_DETACHED                       = 0x400000
	CLONE_FILES                          = 0x400
	CLONE_FS                             = 0x200
	CLONE_IO                             = 0x80000000
	CLONE_NEWCGROUP                      = 0x2000000
	CLONE_NEWIPC                         = 0x8000000
	CLONE_NEWNET                         = 0x40000000
	CLONE_NEWNS                          = 0x20000
	CLONE_NEWPID                         = 0x20000000
	CLONE_NEWUSER                        = 0x10000000
	CLONE_NEWUTS                         = 0x4000000
	CLONE_PARENT                         = 0x8000
	CLONE_PARENT_SETTID                  = 0x100000
	CLONE_PIDFD                          = 0x1000
	CLONE_PTRACE                         = 0x2000
	CLONE_SETTLS                         = 0x80000
	CLONE_SIGHAND                        = 0x800
	CLONE_SYSVSEM                        = 0x40000
	CLONE_THREAD                         = 0x10000
	CLONE_UNTRACED                       = 0x800000
	CLONE_VFORK                          = 0x4000
	CLONE_VM                             = 0x100
	CMSPAR                               = 0x40000000
	CODA_SUPER_MAGIC                     = 0x73757245
	CR0                                  = 0x0
	CR1                                  = 0x200
	CR2                                  = 0x400
	CR3                                  = 0x600
	CRAMFS_MAGIC                         = 0x28cd3d45
	CRDLY                                = 0x600
	CREAD                                = 0x80
	CRTSCTS                              = 0x80000000
	CRYPTO_MAX_NAME                      = 0x40
	CRYPTO_MSG_MAX                       = 0x15
	CRYPTO_NR_MSGTYPES                   = 0x6
	CRYPTO_REPORT_MAXSIZE                = 0x160
	CS5                                  = 0x0
	CS6                                  = 0x10
	CS7                                  = 0x20
	CS8                                  = 0x30
	CSIGNAL                              = 0xff
	CSIZE                                = 0x30
	CSTART                               = 0x11
	CSTATUS                              = 0x0
	CSTOP                                = 0x13
	CSTOPB                               = 0x40
	CSUSP                                = 0x1a
	DAXFS_MAGIC                          = 0x64646178
	DEBUGFS_MAGIC                        = 0x64626720
	DEVPTS_SUPER_MAGIC                   = 0x1cd1
	DMA_BUF_MAGIC                        = 0x444d4142
	DT_BLK                               = 0x6
	DT_CHR                               = 0x2
	DT_DIR                               = 0x4
	DT_FIFO                              = 0x1
	DT_LNK                               = 0xa
	DT_REG                               = 0x8
	DT_SOCK                              = 0xc
	DT_UNKNOWN                           = 0x0
	DT_WHT                               = 0xe
	ECHO                                 = 0x8
	ECHOCTL                              = 0x200
	ECHOE                                = 0x10
	ECHOK                                = 0x20
	ECHOKE                               = 0x800
	ECHONL                               = 0x40
	ECHOPRT                              = 0x400
	ECRYPTFS_SUPER_MAGIC                 = 0xf15f
	EFD_CLOEXEC                          = 0x80000
	EFD_NONBLOCK                         = 0x800
	EFD_SEMAPHORE                        = 0x1
	EFIVARFS_MAGIC                       = 0xde5e81e4
	EFS_SUPER_MAGIC                      = 0x414a53
	ENCODING_DEFAULT                     = 0x0
	ENCODING_FM_MARK                     = 0x3
	ENCODING_FM_SPACE                    = 0x4
	ENCODING_MANCHESTER                  = 0x5
	ENCODING_NRZ                         = 0x1
	ENCODING_NRZI                        = 0x2
	EPOLLERR                             = 0x8
	EPOLLET                              = 0x80000000
	EPOLLEXCLUSIVE                       = 0x10000000
	EPOLLHUP                             = 0x10
	EPOLLIN                              = 0x1
	EPOLLMSG                             = 0x400
	EPOLLONESHOT                         = 0x40000000
	EPOLLOUT                             = 0x4
	EPOLLPRI                             = 0x2
	EPOLLRDBAND                          = 0x80
	EPOLLRDHUP                           = 0x2000
	EPOLLRDNORM                          = 0x40
	EPOLLWAKEUP                          = 0x20000000
	EPOLLWRBAND                          = 0x200
	EPOLLWRNORM                          = 0x100
	EPOLL_CLOEXEC                        = 0x80000
	EPOLL_CTL_ADD                        = 0x1
	EPOLL_CTL_DEL                        = 0x2
	EPOLL_CTL_MOD                        = 0x3
	ETH_P_1588                           = 0x88f7
	ETH_P_8021AD                         = 0x88a8
	ETH_P_8021AH                         = 0x88e7
	ETH_P_8021Q                          = 0x8100
	ETH_P_80221                          = 0x8917
	ETH_P_802_2                          = 0x4
	ETH_P_802_3                          = 0x1
	ETH_P_802_3_MIN                      = 0x600
	ETH_P_802_EX1                        = 0x88b5
	ETH_P_AARP                           = 0x80f3
	ETH_P_AF_IUCV                        = 0xfbfb
	ETH_P_ALL                            = 0x3
	ETH_P_AOE                            = 0x88a2
	ETH_P_ARCNET                         = 0x1a
	ETH_P_ARP                            = 0x806
	ETH_P_ATALK                          = 0x809b
	ETH_P_ATMFATE                        = 0x8884
	ETH_P_ATMMPOA                        = 0x884c
	ETH_P_AX25                           = 0x2
	ETH_P_BATMAN                         = 0x4305
	ETH_P_BPQ                            = 0x8ff
	ETH_P_CAIF                           = 0xf7
	ETH_P_CAN                            = 0xc
	ETH_P_CANFD                          = 0xd
	ETH_P_CONTROL                        = 0x16
	ETH_P_CUST                           = 0x6006
	ETH_P_DDCMP                          = 0x6
	ETH_P_DEC                            = 0x6000
	ETH_P_DIAG                           = 0x6005
	ETH_P_DNA_DL                         = 0x6001
	ETH_P_DNA_RC                         = 0x6002
	ETH_P_DNA_RT                         = 0x6003
	ETH_P_DSA                            = 0x1b
	ETH_P_DSA_8021Q                      = 0xdadb
	ETH_P_ECONET                         = 0x18
	ETH_P_EDSA                           = 0xdada
	ETH_P_ERSPAN                         = 0x88be
	ETH_P_ERSPAN2                        = 0x22eb
	ETH_P_FCOE                           = 0x8906
	ETH_P_FIP                            = 0x8914
	ETH_P_HDLC                           = 0x19
	ETH_P_HSR                            = 0x892f
	ETH_P_IBOE                           = 0x8915
	ETH_P_IEEE802154                     = 0xf6
	ETH_P_IEEEPUP                        = 0xa00
	ETH_P_IEEEPUPAT                      = 0xa01
	ETH_P_IFE                            = 0xed3e
	ETH_P_IP                             = 0x800
	ETH_P_IPV6                           = 0x86dd
	ETH_P_IPX                            = 0x8137
	ETH_P_IRDA                           = 0x17
	ETH_P_LAT                            = 0x6004
	ETH_P_LINK_CTL                       = 0x886c
	ETH_P_LLDP                           = 0x88cc
	ETH_P_LOCALTALK                      = 0x9
	ETH_P_LOOP                           = 0x60
	ETH_P_LOOPBACK                       = 0x9000
	ETH_P_MACSEC                         = 0x88e5
	ETH_P_MAP                            = 0xf9
	ETH_P_MOBITEX                        = 0x15
	ETH_P_MPLS_MC                        = 0x8848
	ETH_P_MPLS_UC                        = 0x8847
	ETH_P_MVRP                           = 0x88f5
	ETH_P_NCSI                           = 0x88f8
	ETH_P_NSH                            = 0x894f
	ETH_P_PAE                            = 0x888e
	ETH_P_PAUSE                          = 0x8808
	ETH_P_PHONET                         = 0xf5
	ETH_P_PPPTALK                        = 0x10
	ETH_P_PPP_DISC                       = 0x8863
	ETH_P_PPP_MP                         = 0x8
	ETH_P_PPP_SES                        = 0x8864
	ETH_P_PREAUTH                        = 0x88c7
	ETH_P_PRP                            = 0x88fb
	ETH_P_PUP                            = 0x200
	ETH_P_PUPAT                          = 0x201
	ETH_P_QINQ1                          = 0x9100
	ETH_P_QINQ2                          = 0x9200
	ETH_P_QINQ3                          = 0x9300
	ETH_P_RARP                           = 0x8035
	ETH_P_SCA                            = 0x6007
	ETH_P_SLOW                           = 0x8809
	ETH_P_SNAP                           = 0x5
	ETH_P_TDLS                           = 0x890d
	ETH_P_TEB                            = 0x6558
	ETH_P_TIPC                           = 0x88ca
	ETH_P_TRAILER                        = 0x1c
	ETH_P_TR_802_2                       = 0x11
	ETH_P_TSN                            = 0x22f0
	ETH_P_WAN_PPP                        = 0x7
	ETH_P_WCCP                           = 0x883e
	ETH_P_X25                            = 0x805
	ETH_P_XDSA                           = 0xf8
	EXABYTE_ENABLE_NEST                  = 0xf0
	EXT2_SUPER_MAGIC                     = 0xef53
	EXT3_SUPER_MAGIC                     = 0xef53
	EXT4_SUPER_MAGIC                     = 0xef53
	EXTA                                 = 0xe
	EXTB                                 = 0xf
	EXTPROC                              = 0x10000
	F2FS_SUPER_MAGIC                     = 0xf2f52010
	FALLOC_FL_COLLAPSE_RANGE             = 0x8
	FALLOC_FL_INSERT_RANGE               = 0x20
	FALLOC_FL_KEEP_SIZE                  = 0x1
	FALLOC_FL_NO_HIDE_STALE              = 0x4
	FALLOC_FL_PUNCH_HOLE                 = 0x2
	FALLOC_FL_UNSHARE_RANGE              = 0x40
	FALLOC_FL_ZERO_RANGE                 = 0x10
	FANOTIFY_METADATA_VERSION            = 0x3
	FAN_ACCESS                           = 0x1
	FAN_ACCESS_PERM                      = 0x20000
	FAN_ALLOW                            = 0x1
	FAN_ALL_CLASS_BITS                   = 0xc
	FAN_ALL_EVENTS                       = 0x3b
	FAN_ALL_INIT_FLAGS                   = 0x3f
	FAN_ALL_MARK_FLAGS                   = 0xff
	FAN_ALL_OUTGOING_EVENTS              = 0x3403b
	FAN_ALL_PERM_EVENTS                  = 0x30000
	FAN_ATTRIB                           = 0x4
	FAN_AUDIT                            = 0x10
	FAN_CLASS_CONTENT                    = 0x4
	FAN_CLASS_NOTIF                      = 0x0
	FAN_CLASS_PRE_CONTENT                = 0x8
	FAN_CLOEXEC                          = 0x1
	FAN_CLOSE                            = 0x18
	FAN_CLOSE_NOWRITE                    = 0x10
	FAN_CLOSE_WRITE                      = 0x8
	FAN_CREATE                           = 0x100
	FAN_DELETE                           = 0x200
	FAN_DELETE_SELF                      = 0x400
	FAN_DENY                             = 0x2
	FAN_ENABLE_AUDIT                     = 0x40
	FAN_EVENT_INFO_TYPE_FID              = 0x1
	FAN_EVENT_METADATA_LEN               = 0x18
	FAN_EVENT_ON_CHILD                   = 0x8000000
	FAN_MARK_ADD                         = 0x1
	FAN_MARK_DONT_FOLLOW                 = 0x4
	FAN_MARK_FILESYSTEM                  = 0x100
	FAN_MARK_FLUSH                       = 0x80
	FAN_MARK_IGNORED_MASK                = 0x20
	FAN_MARK_IGNORED_SURV_MODIFY         = 0x40
	FAN_MARK_INODE                       = 0x0
	FAN_MARK_MOUNT                       = 0x10
	FAN_MARK_ONLYDIR                     = 0x8
	FAN_MARK_REMOVE                      = 0x2
	FAN_MODIFY                           = 0x2
	FAN_MOVE                             = 0xc0
	FAN_MOVED_FROM                       = 0x40
	FAN_MOVED_TO                         = 0x80
	FAN_MOVE_SELF                        = 0x800
	FAN_NOFD                             = -0x1
	FAN_NONBLOCK                         = 0x2
	FAN_ONDIR                            = 0x40000000
	FAN_OPEN                             = 0x20
	FAN_OPEN_EXEC                        = 0x1000
	FAN_OPEN_EXEC_PERM                   = 0x40000
	FAN_OPEN_PERM                        = 0x10000
	FAN_Q_OVERFLOW                       = 0x4000
	FAN_REPORT_FID                       = 0x200
	FAN_REPORT_TID                       = 0x100
	FAN_UNLIMITED_MARKS                  = 0x20
	FAN_UNLIMITED_QUEUE                  = 0x10
	FD_CLOEXEC                           = 0x1
	FD_SETSIZE                           = 0x400
	FF0                                  = 0x0
	FF1                                  = 0x8000
	FFDLY                                = 0x8000
	FLUSHO                               = 0x1000
	FP_XSTATE_MAGIC2                     = 0x46505845
	FS_ENCRYPTION_MODE_ADIANTUM          = 0x9
	FS_ENCRYPTION_MODE_AES_128_CBC       = 0x5
	FS_ENCRYPTION_MODE_AES_128_CTS       = 0x6
	FS_ENCRYPTION_MODE_AES_256_CBC       = 0x3
	FS_ENCRYPTION_MODE_AES_256_CTS       = 0x4
	FS_ENCRYPTION_MODE_AES_256_GCM       = 0x2
	FS_ENCRYPTION_MODE_AES_256_XTS       = 0x1
	FS_ENCRYPTION_MODE_INVALID           = 0x0
	FS_ENCRYPTION_MODE_SPECK128_256_CTS  = 0x8
	FS_ENCRYPTION_MODE_SPECK128_256_XTS  = 0x7
	FS_IOC_GET_ENCRYPTION_POLICY         = 0x400c6615
	FS_IOC_GET_ENCRYPTION_PWSALT         = 0x40106614
	FS_IOC_SET_ENCRYPTION_POLICY         = 0x800c6613
	FS_KEY_DESCRIPTOR_SIZE               = 0x8
	FS_KEY_DESC_PREFIX                   = "fscrypt:"
	FS_KEY_DESC_PREFIX_SIZE              = 0x8
	FS_MAX_KEY_SIZE                      = 0x40
	FS_POLICY_FLAGS_PAD_16               = 0x2
	FS_POLICY_FLAGS_PAD_32               = 0x3
	FS_POLICY_FLAGS_PAD_4                = 0x0
	FS_POLICY_FLAGS_PAD_8                = 0x1
	FS_POLICY_FLAGS_PAD_MASK             = 0x3
	FS_POLICY_FLAGS_VALID                = 0x7
	FUTEXFS_SUPER_MAGIC                  = 0xbad1dea
	F_ADD_SEALS                          = 0x409
	F_DUPFD                              = 0x0
	F_DUPFD_CLOEXEC                      = 0x406
	F_EXLCK                              = 0x4
	F_GETFD                              = 0x1
	F_GETFL                              = 0x3
	F_GETLEASE                           = 0x401
	F_GETLK                              = 0xc
	F_GETLK64                            = 0xc
	F_GETOWN                             = 0x9
	F_GETOWN_EX                          = 0x10
	F_GETPIPE_SZ                         = 0x408
	F_GETSIG                             = 0xb
	F_GET_FILE_RW_HINT                   = 0x40d
	F_GET_RW_HINT                        = 0x40b
	F_GET_SEALS                          = 0x40a
	F_LOCK                               = 0x1
	F_NOTIFY                             = 0x402
	F_OFD_GETLK                          = 0x24
	F_OFD_SETLK                          = 0x25
	F_OFD_SETLKW                         = 0x26
	F_OK                                 = 0x0
	F_RDLCK                              = 0x0
	F_SEAL_FUTURE_WRITE                  = 0x10
	F_SEAL_GROW                          = 0x4
	F_SEAL_SEAL                          = 0x1
	F_SEAL_SHRINK                        = 0x2
	F_SEAL_WRITE                         = 0x8
	F_SETFD                              = 0x2
	F_SETFL                              = 0x4
	F_SETLEASE                           = 0x400
	F_SETLK                              = 0xd
	F_SETLK64                            = 0xd
	F_SETLKW                             = 0xe
	F_SETLKW64                           = 0xe
	F_SETOWN                             = 0x8
	F_SETOWN_EX                          = 0xf
	F_SETPIPE_SZ                         = 0x407
	F_SETSIG                             = 0xa
	F_SET_FILE_RW_HINT                   = 0x40e
	F_SET_RW_HINT                        = 0x40c
	F_SHLCK                              = 0x8
	F_TEST                               = 0x3
	F_TLOCK                              = 0x2
	F_ULOCK                              = 0x0
	F_UNLCK                              = 0x2
	F_WRLCK                              = 0x1
	GENL_ADMIN_PERM                      = 0x1
	GENL_CMD_CAP_DO                      = 0x2
	GENL_CMD_CAP_DUMP                    = 0x4
	GENL_CMD_CAP_HASPOL                  = 0x8
	GENL_HDRLEN                          = 0x4
	GENL_ID_CTRL                         = 0x10
	GENL_ID_PMCRAID                      = 0x12
	GENL_ID_VFS_DQUOT                    = 0x11
	GENL_MAX_ID                          = 0x3ff
	GENL_MIN_ID                          = 0x10
	GENL_NAMSIZ                          = 0x10
	GENL_START_ALLOC                     = 0x13
	GENL_UNS_ADMIN_PERM                  = 0x10
	GRND_NONBLOCK                        = 0x1
	GRND_RANDOM                          = 0x2
	HDIO_DRIVE_CMD                       = 0x31f
	HDIO_DRIVE_CMD_AEB                   = 0x31e
	HDIO_DRIVE_CMD_HDR_SIZE              = 0x4
	HDIO_DRIVE_HOB_HDR_SIZE              = 0x8
	HDIO_DRIVE_RESET                     = 0x31c
	HDIO_DRIVE_TASK                      = 0x31e
	HDIO_DRIVE_TASKFILE                  = 0x31d
	HDIO_DRIVE_TASK_HDR_SIZE             = 0x8
	HDIO_GETGEO                          = 0x301
	HDIO_GET_32BIT                       = 0x309
	HDIO_GET_ACOUSTIC                    = 0x30f
	HDIO_GET_ADDRESS                     = 0x310
	HDIO_GET_BUSSTATE                    = 0x31a
	HDIO_GET_DMA                         = 0x30b
	HDIO_GET_IDENTITY                    = 0x30d
	HDIO_GET_KEEPSETTINGS                = 0x308
	HDIO_GET_MULTCOUNT                   = 0x304
	HDIO_GET_NICE                        = 0x30c
	HDIO_GET_NOWERR                      = 0x30a
	HDIO_GET_QDMA                        = 0x305
	HDIO_GET_UNMASKINTR                  = 0x302
	HDIO_GET_WCACHE                      = 0x30e
	HDIO_OBSOLETE_IDENTITY               = 0x307
	HDIO_SCAN_HWIF                       = 0x328
	HDIO_SET_32BIT                       = 0x324
	HDIO_SET_ACOUSTIC                    = 0x32c
	HDIO_SET_ADDRESS                     = 0x32f
	HDIO_SET_BUSSTATE                    = 0x32d
	HDIO_SET_DMA                         = 0x326
	HDIO_SET_KEEPSETTINGS                = 0x323
	HDIO_SET_MULTCOUNT                   = 0x321
	HDIO_SET_NICE                        = 0x329
	HDIO_SET_NOWERR                      = 0x325
	HDIO_SET_PIO_MODE                    = 0x327
	HDIO_SET_QDMA                        = 0x32e
	HDIO_SET_UNMASKINTR                  = 0x322
	HDIO_SET_WCACHE                      = 0x32b
	HDIO_SET_XFER                        = 0x306
	HDIO_TRISTATE_HWIF                   = 0x31b
	HDIO_UNREGISTER_HWIF                 = 0x32a
	HOSTFS_SUPER_MAGIC                   = 0xc0ffee
	HPFS_SUPER_MAGIC                     = 0xf995e849
	HUGETLBFS_MAGIC                      = 0x958458f6
	HUPCL                                = 0x400
	IBSHIFT                              = 0x10
	ICANON                               = 0x2
	ICMPV6_FILTER                        = 0x1
	ICRNL                                = 0x100
	IEXTEN                               = 0x8000
	IFA_F_DADFAILED                      = 0x8
	IFA_F_DEPRECATED                     = 0x20
	IFA_F_HOMEADDRESS                    = 0x10
	IFA_F_MANAGETEMPADDR                 = 0x100
	IFA_F_MCAUTOJOIN                     = 0x400
	IFA_F_NODAD                          = 0x2
	IFA_F_NOPREFIXROUTE                  = 0x200
	IFA_F_OPTIMISTIC                     = 0x4
	IFA_F_PERMANENT                      = 0x80
	IFA_F_SECONDARY                      = 0x1
	IFA_F_STABLE_PRIVACY                 = 0x800
	IFA_F_TEMPORARY                      = 0x1
	IFA_F_TENTATIVE                      = 0x40
	IFA_MAX                              = 0xa
	IFF_ALLMULTI                         = 0x200
	IFF_ATTACH_QUEUE                     = 0x200
	IFF_AUTOMEDIA                        = 0x4000
	IFF_BROADCAST                        = 0x2
	IFF_DEBUG                            = 0x4
	IFF_DETACH_QUEUE                     = 0x400
	IFF_DORMANT                          = 0x20000
	IFF_DYNAMIC                          = 0x8000
	IFF_ECHO                             = 0x40000
	IFF_LOOPBACK                         = 0x8
	IFF_LOWER_UP                         = 0x10000
	IFF_MASTER                           = 0x400
	IFF_MULTICAST                        = 0x1000
	IFF_MULTI_QUEUE                      = 0x100
	IFF_NAPI                             = 0x10
	IFF_NAPI_FRAGS                       = 0x20
	IFF_NOARP                            = 0x80
	IFF_NOFILTER                         = 0x1000
	IFF_NOTRAILERS                       = 0x20
	IFF_NO_PI                            = 0x1000
	IFF_ONE_QUEUE                        = 0x2000
	IFF_PERSIST                          = 0x800
	IFF_POINTOPOINT                      = 0x10
	IFF_PORTSEL                          = 0x2000
	IFF_PROMISC                          = 0x100
	IFF_RUNNING                          = 0x40
	IFF_SLAVE                            = 0x800
	IFF_TAP                              = 0x2
	IFF_TUN                              = 0x1
	IFF_TUN_EXCL                         = 0x8000
	IFF_UP                               = 0x1
	IFF_VNET_HDR                         = 0x4000
	IFF_VOLATILE                         = 0x70c5a
	IFNAMSIZ                             = 0x10
	IGNBRK                               = 0x1
	IGNCR                                = 0x80
	IGNPAR                               = 0x4
	IMAXBEL                              = 0x2000
	INLCR                                = 0x40
	INPCK                                = 0x10
	IN_ACCESS                            = 0x1
	IN_ALL_EVENTS                        = 0xfff
	IN_ATTRIB                            = 0x4
	IN_CLASSA_HOST                       = 0xffffff
	IN_CLASSA_MAX                        = 0x80
	IN_CLASSA_NET                        = 0xff000000
	IN_CLASSA_NSHIFT                     = 0x18
	IN_CLASSB_HOST                       = 0xffff
	IN_CLASSB_MAX                        = 0x10000
	IN_CLASSB_NET                        = 0xffff0000
	IN_CLASSB_NSHIFT                     = 0x10
	IN_CLASSC_HOST                       = 0xff
	IN_CLASSC_NET                        = 0xffffff00
	IN_CLASSC_NSHIFT                     = 0x8
	IN_CLOEXEC                           = 0x80000
	IN_CLOSE                             = 0x18
	IN_CLOSE_NOWRITE                     = 0x10
	IN_CLOSE_WRITE                       = 0x8
	IN_CREATE                            = 0x100
	IN_DELETE                            = 0x200
	IN_DELETE_SELF                       = 0x400
	IN_DONT_FOLLOW                       = 0x2000000
	IN_EXCL_UNLINK                       = 0x4000000
	IN_IGNORED                           = 0x8000
	IN_ISDIR                             = 0x40000000
	IN_LOOPBACKNET                       = 0x7f
	IN_MASK_ADD                          = 0x20000000
	IN_MASK_CREATE                       = 0x10000000
	IN_MODIFY                            = 0x2
	IN_MOVE                              = 0xc0
	IN_MOVED_FROM                        = 0x40
	IN_MOVED_TO                          = 0x80
	IN_MOVE_SELF                         = 0x800
	IN_NONBLOCK                          = 0x800
	IN_ONESHOT                           = 0x80000000
	IN_ONLYDIR                           = 0x1000000
	IN_OPEN                              = 0x20
	IN_Q_OVERFLOW                        = 0x4000
	IN_UNMOUNT                           = 0x2000
	IOCTL_VM_SOCKETS_GET_LOCAL_CID       = 0x7b9
	IPPROTO_AH                           = 0x33
	IPPROTO_BEETPH                       = 0x5e
	IPPROTO_COMP                         = 0x6c
	IPPROTO_DCCP                         = 0x21
	IPPROTO_DSTOPTS                      = 0x3c
	IPPROTO_EGP                          = 0x8
	IPPROTO_ENCAP                        = 0x62
	IPPROTO_ESP                          = 0x32
	IPPROTO_FRAGMENT                     = 0x2c
	IPPROTO_GRE                          = 0x2f
	IPPROTO_HOPOPTS                      = 0x0
	IPPROTO_ICMP                         = 0x1
	IPPROTO_ICMPV6                       = 0x3a
	IPPROTO_IDP                          = 0x16
	IPPROTO_IGMP                         = 0x2
	IPPROTO_IP                           = 0x0
	IPPROTO_IPIP                         = 0x4
	IPPROTO_IPV6                         = 0x29
	IPPROTO_MH                           = 0x87
	IPPROTO_MPLS                         = 0x89
	IPPROTO_MTP                          = 0x5c
	IPPROTO_NONE                         = 0x3b
	IPPROTO_PIM                          = 0x67
	IPPROTO_PUP                          = 0xc
	IPPROTO_RAW                          = 0xff
	IPPROTO_ROUTING                      = 0x2b
	IPPROTO_RSVP                         = 0x2e
	IPPROTO_SCTP                         = 0x84
	IPPROTO_TCP                          = 0x6
	IPPROTO_TP                           = 0x1d
	IPPROTO_UDP                          = 0x11
	IPPROTO_UDPLITE                      = 0x88
	IPV6_2292DSTOPTS                     = 0x4
	IPV6_2292HOPLIMIT                    = 0x8
	IPV6_2292HOPOPTS                     = 0x3
	IPV6_2292PKTINFO                     = 0x2
	IPV6_2292PKTOPTIONS                  = 0x6
	IPV6_2292RTHDR                       = 0x5
	IPV6_ADDRFORM                        = 0x1
	IPV6_ADDR_PREFERENCES                = 0x48
	IPV6_ADD_MEMBERSHIP                  = 0x14
	IPV6_AUTHHDR                         = 0xa
	IPV6_AUTOFLOWLABEL                   = 0x46
	IPV6_CHECKSUM                        = 0x7
	IPV6_DONTFRAG                        = 0x3e
	IPV6_DROP_MEMBERSHIP                 = 0x15
	IPV6_DSTOPTS                         = 0x3b
	IPV6_FREEBIND                        = 0x4e
	IPV6_HDRINCL                         = 0x24
	IPV6_HOPLIMIT                        = 0x34
	IPV6_HOPOPTS                         = 0x36
	IPV6_IPSEC_POLICY                    = 0x22
	IPV6_JOIN_ANYCAST                    = 0x1b
	IPV6_JOIN_GROUP                      = 0x14
	IPV6_LEAVE_ANYCAST                   = 0x1c
	IPV6_LEAVE_GROUP                     = 0x15
	IPV6_MINHOPCOUNT                     = 0x49
	IPV6_MTU                             = 0x18
	IPV6_MTU_DISCOVER                    = 0x17
	IPV6_MULTICAST_ALL                   = 0x1d
	IPV6_MULTICAST_HOPS                  = 0x12
	IPV6_MULTICAST_IF                    = 0x11
	IPV6_MULTICAST_LOOP                  = 0x13
	IPV6_NEXTHOP                         = 0x9
	IPV6_ORIGDSTADDR                     = 0x4a
	IPV6_PATHMTU                         = 0x3d
	IPV6_PKTINFO                         = 0x32
	IPV6_PMTUDISC_DO                     = 0x2
	IPV6_PMTUDISC_DONT                   = 0x0
	IPV6_PMTUDISC_INTERFACE              = 0x4
	IPV6_PMTUDISC_OMIT                   = 0x5
	IPV6_PMTUDISC_PROBE                  = 0x3
	IPV6_PMTUDISC_WANT                   = 0x1
	IPV6_RECVDSTOPTS                     = 0x3a
	IPV6_RECVERR                         = 0x19
	IPV6_RECVFRAGSIZE                    = 0x4d
	IPV6_RECVHOPLIMIT                    = 0x33
	IPV6_RECVHOPOPTS                     = 0x35
	IPV6_RECVORIGDSTADDR                 = 0x4a
	IPV6_RECVPATHMTU                     = 0x3c
	IPV6_RECVPKTINFO                     = 0x31
	IPV6_RECVRTHDR                       = 0x38
	IPV6_RECVTCLASS                      = 0x42
	IPV6_ROUTER_ALERT                    = 0x16
	IPV6_ROUTER_ALERT_ISOLATE            = 0x1e
	IPV6_RTHDR                           = 0x39
	IPV6_RTHDRDSTOPTS                    = 0x37
	IPV6_RTHDR_LOOSE                     = 0x0
	IPV6_RTHDR_STRICT                    = 0x1
	IPV6_RTHDR_TYPE_0                    = 0x0
	IPV6_RXDSTOPTS                       = 0x3b
	IPV6_RXHOPOPTS                       = 0x36
	IPV6_TCLASS                          = 0x43
	IPV6_TRANSPARENT                     = 0x4b
	IPV6_UNICAST_HOPS                    = 0x10
	IPV6_UNICAST_IF                      = 0x4c
	IPV6_V6ONLY                          = 0x1a
	IPV6_XFRM_POLICY                     = 0x23
	IP_ADD_MEMBERSHIP                    = 0x23
	IP_ADD_SOURCE_MEMBERSHIP             = 0x27
	IP_BIND_ADDRESS_NO_PORT              = 0x18
	IP_BLOCK_SOURCE                      = 0x26
	IP_CHECKSUM                          = 0x17
	IP_DEFAULT_MULTICAST_LOOP            = 0x1
	IP_DEFAULT_MULTICAST_TTL             = 0x1
	IP_DF                                = 0x4000
	IP_DROP_MEMBERSHIP                   = 0x24
	IP_DROP_SOURCE_MEMBERSHIP            = 0x28
	IP_FREEBIND                          = 0xf
	IP_HDRINCL                           = 0x3
	IP_IPSEC_POLICY                      = 0x10
	IP_MAXPACKET                         = 0xffff
	IP_MAX_MEMBERSHIPS                   = 0x14
	IP_MF                                = 0x2000
	IP_MINTTL                            = 0x15
	IP_MSFILTER                          = 0x29
	IP_MSS                               = 0x240
	IP_MTU                               = 0xe
	IP_MTU_DISCOVER                      = 0xa
	IP_MULTICAST_ALL                     = 0x31
	IP_MULTICAST_IF                      = 0x20
	IP_MULTICAST_LOOP                    = 0x22
	IP_MULTICAST_TTL                     = 0x21
	IP_NODEFRAG                          = 0x16
	IP_OFFMASK                           = 0x1fff
	IP_OPTIONS                           = 0x4
	IP_ORIGDSTADDR                       = 0x14
	IP_PASSSEC                           = 0x12
	IP_PKTINFO                           = 0x8
	IP_PKTOPTIONS                        = 0x9
	IP_PMTUDISC                          = 0xa
	IP_PMTUDISC_DO                       = 0x2
	IP_PMTUDISC_DONT                     = 0x0
	IP_PMTUDISC_INTERFACE                = 0x4
	IP_PMTUDISC_OMIT                     = 0x5
	IP_PMTUDISC_PROBE                    = 0x3
	IP_PMTUDISC_WANT                     = 0x1
	IP_RECVERR                           = 0xb
	IP_RECVFRAGSIZE                      = 0x19
	IP_RECVOPTS                          = 0x6
	IP_RECVORIGDSTADDR                   = 0x14
	IP_RECVRETOPTS                       = 0x7
	IP_RECVTOS                           = 0xd
	IP_RECVTTL                           = 0xc
	IP_RETOPTS                           = 0x7
	IP_RF                                = 0x8000
	IP_ROUTER_ALERT                      = 0x5
	IP_TOS                               = 0x1
	IP_TRANSPARENT                       = 0x13
	IP_TTL                               = 0x2
	IP_UNBLOCK_SOURCE                    = 0x25
	IP_UNICAST_IF                        = 0x32
	IP_XFRM_POLICY                       = 0x11
	ISIG                                 = 0x1
	ISOFS_SUPER_MAGIC                    = 0x9660
	ISTRIP                               = 0x20
	IUCLC                                = 0x200
	IUTF8                                = 0x4000
	IXANY                                = 0x800
	IXOFF                                = 0x1000
	IXON                                 = 0x400
	JFFS2_SUPER_MAGIC                    = 0x72b6
	KEXEC_ARCH_386                       = 0x30000
	KEXEC_ARCH_68K                       = 0x40000
	KEXEC_ARCH_AARCH64                   = 0xb70000
	KEXEC_ARCH_ARM                       = 0x280000
	KEXEC_ARCH_DEFAULT                   = 0x0
	KEXEC_ARCH_IA_64                     = 0x320000
	KEXEC_ARCH_MASK                      = 0xffff0000
	KEXEC_ARCH_MIPS                      = 0x80000
	KEXEC_ARCH_MIPS_LE                   = 0xa0000
	KEXEC_ARCH_PPC                       = 0x140000
	KEXEC_ARCH_PPC64                     = 0x150000
	KEXEC_ARCH_S390                      = 0x160000
	KEXEC_ARCH_SH                        = 0x2a0000
	KEXEC_ARCH_X86_64                    = 0x3e0000
	KEXEC_FILE_NO_INITRAMFS              = 0x4
	KEXEC_FILE_ON_CRASH                  = 0x2
	KEXEC_FILE_UNLOAD                    = 0x1
	KEXEC_ON_CRASH                       = 0x1
	KEXEC_PRESERVE_CONTEXT               = 0x2
	KEXEC_SEGMENT_MAX                    = 0x10
	KEYCTL_ASSUME_AUTHORITY              = 0x10
	KEYCTL_CAPABILITIES                  = 0x1f
	KEYCTL_CAPS0_BIG_KEY                 = 0x10
	KEYCTL_CAPS0_CAPABILITIES            = 0x1
	KEYCTL_CAPS0_DIFFIE_HELLMAN          = 0x4
	KEYCTL_CAPS0_INVALIDATE              = 0x20
	KEYCTL_CAPS0_MOVE                    = 0x80
	KEYCTL_CAPS0_PERSISTENT_KEYRINGS     = 0x2
	KEYCTL_CAPS0_PUBLIC_KEY              = 0x8
	KEYCTL_CAPS0_RESTRICT_KEYRING        = 0x40
	KEYCTL_CAPS1_NS_KEYRING_NAME         = 0x1
	KEYCTL_CAPS1_NS_KEY_TAG              = 0x2
	KEYCTL_CHOWN                         = 0x4
	KEYCTL_CLEAR                         = 0x7
	KEYCTL_DESCRIBE                      = 0x6
	KEYCTL_DH_COMPUTE                    = 0x17
	KEYCTL_GET_KEYRING_ID                = 0x0
	KEYCTL_GET_PERSISTENT                = 0x16
	KEYCTL_GET_SECURITY                  = 0x11
	KEYCTL_INSTANTIATE                   = 0xc
	KEYCTL_INSTANTIATE_IOV               = 0x14
	KEYCTL_INVALIDATE                    = 0x15
	KEYCTL_JOIN_SESSION_KEYRING          = 0x1
	KEYCTL_LINK                          = 0x8
	KEYCTL_MOVE                          = 0x1e
	KEYCTL_MOVE_EXCL                     = 0x1
	KEYCTL_NEGATE                        = 0xd
	KEYCTL_PKEY_DECRYPT                  = 0x1a
	KEYCTL_PKEY_ENCRYPT                  = 0x19
	KEYCTL_PKEY_QUERY                    = 0x18
	KEYCTL_PKEY_SIGN                     = 0x1b
	KEYCTL_PKEY_VERIFY                   = 0x1c
	KEYCTL_READ                          = 0xb
	KEYCTL_REJECT                        = 0x13
	KEYCTL_RESTRICT_KEYRING              = 0x1d
	KEYCTL_REVOKE                        = 0x3
	KEYCTL_SEARCH                        = 0xa
	KEYCTL_SESSION_TO_PARENT             = 0x12
	KEYCTL_SETPERM                       = 0x5
	KEYCTL_SET_REQKEY_KEYRING            = 0xe
	KEYCTL_SET_TIMEOUT                   = 0xf
	KEYCTL_SUPPORTS_DECRYPT              = 0x2
	KEYCTL_SUPPORTS_ENCRYPT              = 0x1
	KEYCTL_SUPPORTS_SIGN                 = 0x4
	KEYCTL_SUPPORTS_VERIFY               = 0x8
	KEYCTL_UNLINK                        = 0x9
	KEYCTL_UPDATE                        = 0x2
	KEY_REQKEY_DEFL_DEFAULT              = 0x0
	KEY_REQKEY_DEFL_GROUP_KEYRING        = 0x6
	KEY_REQKEY_DEFL_NO_CHANGE            = -0x1
	KEY_REQKEY_DEFL_PROCESS_KEYRING      = 0x2
	KEY_REQKEY_DEFL_REQUESTOR_KEYRING    = 0x7
	KEY_REQKEY_DEFL_SESSION_KEYRING      = 0x3
	KEY_REQKEY_DEFL_THREAD_KEYRING       = 0x1
	KEY_REQKEY_DEFL_USER_KEYRING         = 0x4
	KEY_REQKEY_DEFL_USER_SESSION_KEYRING = 0x5
	KEY_SPEC_GROUP_KEYRING               = -0x6
	KEY_SPEC_PROCESS_KEYRING             = -0x2
	KEY_SPEC_REQKEY_AUTH_KEY             = -0x7
	KEY_SPEC_REQUESTOR_KEYRING           = -0x8
	KEY_SPEC_SESSION_KEYRING             = -0x3
	KEY_SPEC_THREAD_KEYRING              = -0x1
	KEY_SPEC_USER_KEYRING                = -0x4
	KEY_SPEC_USER_SESSION_KEYRING        = -0x5
	LINUX_REBOOT_CMD_CAD_OFF             = 0x0
	LINUX_REBOOT_CMD_CAD_ON              = 0x89abcdef
	LINUX_REBOOT_CMD_HALT                = 0xcdef0123
	LINUX_REBOOT_CMD_KEXEC               = 0x45584543
	LINUX_REBOOT_CMD_POWER_OFF           = 0x4321fedc
	LINUX_REBOOT_CMD_RESTART             = 0x1234567
	LINUX_REBOOT_CMD_RESTART2            = 0xa1b2c3d4
	LINUX_REBOOT_CMD_SW_SUSPEND          = 0xd000fce2
	LINUX_REBOOT_MAGIC1                  = 0xfee1dead
	LINUX_REBOOT_MAGIC2                  = 0x28121969
	LOCK_EX                              = 0x2
	LOCK_NB                              = 0x4
	LOCK_SH                              = 0x1
	LOCK_UN                              = 0x8
	LOOP_CLR_FD                          = 0x4c01
	LOOP_CTL_ADD                         = 0x4c80
	LOOP_CTL_GET_FREE                    = 0x4c82
	LOOP_CTL_REMOVE                      = 0x4c81
	LOOP_GET_STATUS                      = 0x4c03
	LOOP_GET_STATUS64                    = 0x4c05
	LOOP_SET_BLOCK_SIZE                  = 0x4c09
	LOOP_SET_CAPACITY                    = 0x4c07
	LOOP_SET_DIRECT_IO                   = 0x4c08
	LOOP_SET_FD                          = 0x4c00
	LOOP_SET_STATUS                      = 0x4c02
	LOOP_SET_STATUS64                    = 0x4c04
	LO_KEY_SIZE                          = 0x20
	LO_NAME_SIZE                         = 0x40
	MADV_DODUMP                          = 0x11
	MADV_DOFORK                          = 0xb
	MADV_DONTDUMP                        = 0x10
	MADV_DONTFORK                        = 0xa
	MADV_DONTNEED                        = 0x4
	MADV_FREE                            = 0x8
	MADV_HUGEPAGE                        = 0xe
	MADV_HWPOISON                        = 0x64
	MADV_KEEPONFORK                      = 0x13
	MADV_MERGEABLE                       = 0xc
	MADV_NOHUGEPAGE                      = 0xf
	MADV_NORMAL                          = 0x0
	MADV_RANDOM                          = 0x1
	MADV_REMOVE                          = 0x9
	MADV_SEQUENTIAL                      = 0x2
	MADV_UNMERGEABLE                     = 0xd
	MADV_WILLNEED                        = 0x3
	MADV_WIPEONFORK                      = 0x12
	MAP_32BIT                            = 0x40
	MAP_ANON                             = 0x20
	MAP_ANONYMOUS                        = 0x20
	MAP_DENYWRITE                        = 0x800
	MAP_EXECUTABLE                       = 0x1000
	MAP_FILE                             = 0x0
	MAP_FIXED                            = 0x10
	MAP_FIXED_NOREPLACE                  = 0x100000
	MAP_GROWSDOWN                        = 0x100
	MAP_HUGETLB                          = 0x40000
	MAP_HUGE_MASK                        = 0x3f
	MAP_HUGE_SHIFT                       = 0x1a
	MAP_LOCKED                           = 0x2000
	MAP_NONBLOCK                         = 0x10000
	MAP_NORESERVE                        = 0x4000
	MAP_POPULATE                         = 0x8000
	MAP_PRIVATE                          = 0x2
	MAP_SHARED                           = 0x1
	MAP_SHARED_VALIDATE                  = 0x3
	MAP_STACK                            = 0x20000
	MAP_SYNC                             = 0x80000
	MAP_TYPE                             = 0xf
	MCAST_BLOCK_SOURCE                   = 0x2b
	MCAST_EXCLUDE                        = 0x0
	MCAST_INCLUDE                        = 0x1
	MCAST_JOIN_GROUP                     = 0x2a
	MCAST_JOIN_SOURCE_GROUP              = 0x2e
	MCAST_LEAVE_GROUP                    = 0x2d
	MCAST_LEAVE_SOURCE_GROUP             = 0x2f
	MCAST_MSFILTER                       = 0x30
	MCAST_UNBLOCK_SOURCE                 = 0x2c
	MCL_CURRENT                          = 0x1
	MCL_FUTURE                           = 0x2
	MCL_ONFAULT                          = 0x4
	MFD_ALLOW_SEALING                    = 0x2
	MFD_CLOEXEC                          = 0x1
	MFD_HUGETLB                          = 0x4
	MFD_HUGE_16GB                        = -0x78000000
	MFD_HUGE_16MB                        = 0x60000000
	MFD_HUGE_1GB                         = 0x78000000
	MFD_HUGE_1MB                         = 0x50000000
	MFD_HUGE_256MB                       = 0x70000000
	MFD_HUGE_2GB                         = 0x7c000000
	MFD_HUGE_2MB                         = 0x54000000
	MFD_HUGE_32MB                        = 0x64000000
	MFD_HUGE_512KB                       = 0x4c000000
	MFD_HUGE_512MB                       = 0x74000000
	MFD_HUGE_64KB                        = 0x40000000
	MFD_HUGE_8MB                         = 0x5c000000
	MFD_HUGE_MASK                        = 0x3f
	MFD_HUGE_SHIFT                       = 0x1a
	MINIX2_SUPER_MAGIC                   = 0x2468
	MINIX2_SUPER_MAGIC2                  = 0x2478
	MINIX3_SUPER_MAGIC                   = 0x4d5a
	MINIX_SUPER_MAGIC                    = 0x137f
	MINIX_SUPER_MAGIC2                   = 0x138f
	MNT_DETACH                           = 0x2
	MNT_EXPIRE                           = 0x4
	MNT_FORCE                            = 0x1
	MODULE_INIT_IGNORE_MODVERSIONS       = 0x1
	MODULE_INIT_IGNORE_VERMAGIC          = 0x2
	MSDOS_SUPER_MAGIC                    = 0x4d44
	MSG_BATCH                            = 0x40000
	MSG_CMSG_CLOEXEC                     = 0x40000000
	MSG_CONFIRM                          = 0x800
	MSG_CTRUNC                           = 0x8
	MSG_DONTROUTE                        = 0x4
	MSG_DONTWAIT                         = 0x40
	MSG_EOR                              = 0x80
	MSG_ERRQUEUE                         = 0x2000
	MSG_FASTOPEN                         = 0x20000000
	MSG_FIN                              = 0x200
	MSG_MORE                             = 0x8000
	MSG_NOSIGNAL                         = 0x4000
	MSG_OOB                              = 0x1
	MSG_PEEK                             = 0x2
	MSG_PROXY                            = 0x10
	MSG_RST                              = 0x1000
	MSG_SYN                              = 0x400
	MSG_TRUNC                            = 0x20
	MSG_TRYHARD                          = 0x4
	MSG_WAITALL                          = 0x100
	MSG_WAITFORONE                       = 0x10000
	MSG_ZEROCOPY                         = 0x4000000
	MS_ACTIVE                            = 0x40000000
	MS_ASYNC                             = 0x1
	MS_BIND                              = 0x1000
	MS_BORN                              = 0x20000000
	MS_DIRSYNC                           = 0x80
	MS_INVALIDATE                        = 0x2
	MS_I_VERSION                         = 0x800000
	MS_KERNMOUNT                         = 0x400000
	MS_LAZYTIME                          = 0x2000000
	MS_MANDLOCK                          = 0x40
	MS_MGC_MSK                           = 0xffff0000
	MS_MGC_VAL                           = 0xc0ed0000
	MS_MOVE                              = 0x2000
	MS_NOATIME                           = 0x400
	MS_NODEV                             = 0x4
	MS_NODIRATIME                        = 0x800
	MS_NOEXEC                            = 0x8
	MS_NOREMOTELOCK                      = 0x8000000
	MS_NOSEC                             = 0x10000000
	MS_NOSUID                            = 0x2
	MS_NOUSER                            = -0x80000000
	MS_POSIXACL                          = 0x10000
	MS_PRIVATE                           = 0x40000
	MS_RDONLY                            = 0x1
	MS_REC                               = 0x4000
	MS_RELATIME                          = 0x200000
	MS_REMOUNT                           = 0x20
	MS_RMT_MASK                          = 0x2800051
	MS_SHARED                            = 0x100000
	MS_SILENT                            = 0x8000
	MS_SLAVE                             = 0x80000
	MS_STRICTATIME                       = 0x1000000
	MS_SUBMOUNT                          = 0x4000000
	MS_SYNC                              = 0x4
	MS_SYNCHRONOUS                       = 0x10
	MS_UNBINDABLE                        = 0x20000
	MS_VERBOSE                           = 0x8000
	MTD_INODE_FS_MAGIC                   = 0x11307854
	NAME_MAX                             = 0xff
	NCP_SUPER_MAGIC                      = 0x564c
	NETLINK_ADD_MEMBERSHIP               = 0x1
	NETLINK_AUDIT                        = 0x9
	NETLINK_BROADCAST_ERROR              = 0x4
	NETLINK_CAP_ACK                      = 0xa
	NETLINK_CONNECTOR                    = 0xb
	NETLINK_CRYPTO                       = 0x15
	NETLINK_DNRTMSG                      = 0xe
	NETLINK_DROP_MEMBERSHIP              = 0x2
	NETLINK_ECRYPTFS                     = 0x13
	NETLINK_EXT_ACK                      = 0xb
	NETLINK_FIB_LOOKUP                   = 0xa
	NETLINK_FIREWALL                     = 0x3
	NETLINK_GENERIC                      = 0x10
	NETLINK_GET_STRICT_CHK               = 0xc
	NETLINK_INET_DIAG                    = 0x4
	NETLINK_IP6_FW                       = 0xd
	NETLINK_ISCSI                        = 0x8
	NETLINK_KOBJECT_UEVENT               = 0xf
	NETLINK_LISTEN_ALL_NSID              = 0x8
	NETLINK_LIST_MEMBERSHIPS             = 0x9
	NETLINK_NETFILTER                    = 0xc
	NETLINK_NFLOG                        = 0x5
	NETLINK_NO_ENOBUFS                   = 0x5
	NETLINK_PKTINFO                      = 0x3
	NETLINK_RDMA                         = 0x14
	NETLINK_ROUTE                        = 0x0
	NETLINK_RX_RING                      = 0x6
	NETLINK_SCSITRANSPORT                = 0x12
	NETLINK_SELINUX                      = 0x7
	NETLINK_SMC                          = 0x16
	NETLINK_SOCK_DIAG                    = 0x4
	NETLINK_TX_RING                      = 0x7
	NETLINK_UNUSED                       = 0x1
	NETLINK_USERSOCK                     = 0x2
	NETLINK_XFRM                         = 0x6
	NETNSA_MAX                           = 0x5
	NETNSA_NSID_NOT_ASSIGNED             = -0x1
	NFDBITS                              = 0x20
	NFNETLINK_V0                         = 0x0
	NFNLGRP_ACCT_QUOTA                   = 0x8
	NFNLGRP_CONNTRACK_DESTROY            = 0x3
	NFNLGRP_CONNTRACK_EXP_DESTROY        = 0x6
	NFNLGRP_CONNTRACK_EXP_NEW            = 0x4
	NFNLGRP_CONNTRACK_EXP_UPDATE         = 0x5
	NFNLGRP_CONNTRACK_NEW                = 0x1
	NFNLGRP_CONNTRACK_UPDATE             = 0x2
	NFNLGRP_MAX                          = 0x9
	NFNLGRP_NFTABLES                     = 0x7
	NFNLGRP_NFTRACE                      = 0x9
	NFNLGRP_NONE                         = 0x0
	NFNL_BATCH_MAX                       = 0x1
	NFNL_MSG_BATCH_BEGIN                 = 0x10
	NFNL_MSG_BATCH_END                   = 0x11
	NFNL_NFA_NEST                        = 0x8000
	NFNL_SUBSYS_ACCT                     = 0x7
	NFNL_SUBSYS_COUNT                    = 0xc
	NFNL_SUBSYS_CTHELPER                 = 0x9
	NFNL_SUBSYS_CTNETLINK                = 0x1
	NFNL_SUBSYS_CTNETLINK_EXP            = 0x2
	NFNL_SUBSYS_CTNETLINK_TIMEOUT        = 0x8
	NFNL_SUBSYS_IPSET                    = 0x6
	NFNL_SUBSYS_NFTABLES                 = 0xa
	NFNL_SUBSYS_NFT_COMPAT               = 0xb
	NFNL_SUBSYS_NONE                     = 0x0
	NFNL_SUBSYS_OSF                      = 0x5
	NFNL_SUBSYS_QUEUE                    = 0x3
	NFNL_SUBSYS_ULOG                     = 0x4
	NFS_SUPER_MAGIC                      = 0x6969
	NILFS_SUPER_MAGIC                    = 0x3434
	NL0                                  = 0x0
	NL1                                  = 0x100
	NLA_ALIGNTO                          = 0x4
	NLA_F_NESTED                         = 0x8000
	NLA_F_NET_BYTEORDER                  = 0x4000
	NLA_HDRLEN                           = 0x4
	NLDLY                                = 0x100
	NLMSG_ALIGNTO                        = 0x4
	NLMSG_DONE                           = 0x3
	NLMSG_ERROR                          = 0x2
	NLMSG_HDRLEN                         = 0x10
	NLMSG_MIN_TYPE                       = 0x10
	NLMSG_NOOP                           = 0x1
	NLMSG_OVERRUN                        = 0x4
	NLM_F_ACK                            = 0x4
	NLM_F_ACK_TLVS                       = 0x200
	NLM_F_APPEND                         = 0x800
	NLM_F_ATOMIC                         = 0x400
	NLM_F_CAPPED                         = 0x100
	NLM_F_CREATE                         = 0x400
	NLM_F_DUMP                           = 0x300
	NLM_F_DUMP_FILTERED                  = 0x20
	NLM_F_DUMP_INTR                      = 0x10
	NLM_F_ECHO                           = 0x8
	NLM_F_EXCL                           = 0x200
	NLM_F_MATCH                          = 0x200
	NLM_F_MULTI                          = 0x2
	NLM_F_NONREC                         = 0x100
	NLM_F_REPLACE                        = 0x100
	NLM_F_REQUEST                        = 0x1
	NLM_F_ROOT                           = 0x100
	NOFLSH                               = 0x80
	NSFS_MAGIC                           = 0x6e736673
	NS_GET_NSTYPE                        = 0xb703
	NS_GET_OWNER_UID                     = 0xb704
	NS_GET_PARENT                        = 0xb702
	NS_GET_USERNS                        = 0xb701
	OCFS2_SUPER_MAGIC                    = 0x7461636f
	OCRNL                                = 0x8
	OFDEL                                = 0x80
	OFILL                                = 0x40
	OLCUC                                = 0x2
	ONLCR                                = 0x4
	ONLRET                               = 0x20
	ONOCR                                = 0x10
	OPENPROM_SUPER_MAGIC                 = 0x9fa1
	OPOST                                = 0x1
	OVERLAYFS_SUPER_MAGIC                = 0x794c7630
	O_ACCMODE                            = 0x3
	O_APPEND                             = 0x400
	O_ASYNC                              = 0x2000
	O_CLOEXEC                            = 0x80000
	O_CREAT                              = 0x40
	O_DIRECT                             = 0x4000
	O_DIRECTORY                          = 0x10000
	O_DSYNC                              = 0x1000
	O_EXCL                               = 0x80
	O_FSYNC                              = 0x101000
	O_LARGEFILE                          = 0x8000
	O_NDELAY                             = 0x800
	O_NOATIME                            = 0x40000
	O_NOCTTY                             = 0x100
	O_NOFOLLOW                           = 0x20000
	O_NONBLOCK                           = 0x800
	O_PATH                               = 0x200000
	O_RDONLY                             = 0x0
	O_RDWR                               = 0x2
	O_RSYNC                              = 0x101000
	O_SYNC                               = 0x101000
	O_TMPFILE                            = 0x410000
	O_TRUNC                              = 0x200
	O_WRONLY                             = 0x1
	PACKET_ADD_MEMBERSHIP                = 0x1
	PACKET_AUXDATA                       = 0x8
	PACKET_BROADCAST                     = 0x1
	PACKET_COPY_THRESH                   = 0x7
	PACKET_DROP_MEMBERSHIP               = 0x2
	PACKET_FANOUT                        = 0x12
	PACKET_FANOUT_CBPF                   = 0x6
	PACKET_FANOUT_CPU                    = 0x2
	PACKET_FANOUT_DATA                   = 0x16
	PACKET_FANOUT_EBPF                   = 0x7
	PACKET_FANOUT_FLAG_DEFRAG            = 0x8000
	PACKET_FANOUT_FLAG_ROLLOVER          = 0x1000
	PACKET_FANOUT_FLAG_UNIQUEID          = 0x2000
	PACKET_FANOUT_HASH                   = 0x0
	PACKET_FANOUT_LB                     = 0x1
	PACKET_FANOUT_QM                     = 0x5
	PACKET_FANOUT_RND                    = 0x4
	PACKET_FANOUT_ROLLOVER               = 0x3
	PACKET_FASTROUTE                     = 0x6
	PACKET_HDRLEN                        = 0xb
	PACKET_HOST                          = 0x0
	PACKET_IGNORE_OUTGOING               = 0x17
	PACKET_KERNEL                        = 0x7
	PACKET_LOOPBACK                      = 0x5
	PACKET_LOSS                          = 0xe
	PACKET_MR_ALLMULTI                   = 0x2
	PACKET_MR_MULTICAST                  = 0x0
	PACKET_MR_PROMISC                    = 0x1
	PACKET_MR_UNICAST                    = 0x3
	PACKET_MULTICAST                     = 0x2
	PACKET_ORIGDEV                       = 0x9
	PACKET_OTHERHOST                     = 0x3
	PACKET_OUTGOING                      = 0x4
	PACKET_QDISC_BYPASS                  = 0x14
	PACKET_RECV_OUTPUT                   = 0x3
	PACKET_RESERVE                       = 0xc
	PACKET_ROLLOVER_STATS                = 0x15
	PACKET_RX_RING                       = 0x5
	PACKET_STATISTICS                    = 0x6
	PACKET_TIMESTAMP                     = 0x11
	PACKET_TX_HAS_OFF                    = 0x13
	PACKET_TX_RING                       = 0xd
	PACKET_TX_TIMESTAMP                  = 0x10
	PACKET_USER                          = 0x6
	PACKET_VERSION                       = 0xa
	PACKET_VNET_HDR                      = 0xf
	PARENB                               = 0x100
	PARITY_CRC16_PR0                     = 0x2
	PARITY_CRC16_PR0_CCITT               = 0x4
	PARITY_CRC16_PR1                     = 0x3
	PARITY_CRC16_PR1_CCITT               = 0x5
	PARITY_CRC32_PR0_CCITT               = 0x6
	PARITY_CRC32_PR1_CCITT               = 0x7
	PARITY_DEFAULT                       = 0x0
	PARITY_NONE                          = 0x1
	PARMRK                               = 0x8
	PARODD                               = 0x200
	PENDIN                               = 0x4000
	PERF_EVENT_IOC_DISABLE               = 0x2401
	PERF_EVENT_IOC_ENABLE                = 0x2400
	PERF_EVENT_IOC_ID                    = 0x80042407
	PERF_EVENT_IOC_MODIFY_ATTRIBUTES     = 0x4004240b
	PERF_EVENT_IOC_PAUSE_OUTPUT          = 0x40042409
	PERF_EVENT_IOC_PERIOD                = 0x40082404
	PERF_EVENT_IOC_QUERY_BPF             = 0xc004240a
	PERF_EVENT_IOC_REFRESH               = 0x2402
	PERF_EVENT_IOC_RESET                 = 0x2403
	PERF_EVENT_IOC_SET_BPF               = 0x40042408
	PERF_EVENT_IOC_SET_FILTER            = 0x40042406
	PERF_EVENT_IOC_SET_OUTPUT            = 0x2405
	PIPEFS_MAGIC                         = 0x50495045
	PPPIOCATTACH                         = 0x4004743d
	PPPIOCATTCHAN                        = 0x40047438
	PPPIOCCONNECT                        = 0x4004743a
	PPPIOCDETACH                         = 0x4004743c
	PPPIOCDISCONN                        = 0x7439
	PPPIOCGASYNCMAP                      = 0x80047458
	PPPIOCGCHAN                          = 0x80047437
	PPPIOCGDEBUG                         = 0x80047441
	PPPIOCGFLAGS                         = 0x8004745a
	PPPIOCGIDLE                          = 0x8008743f
	PPPIOCGL2TPSTATS                     = 0x80487436
	PPPIOCGMRU                           = 0x80047453
	PPPIOCGNPMODE                        = 0xc008744c
	PPPIOCGRASYNCMAP                     = 0x80047455
	PPPIOCGUNIT                          = 0x80047456
	PPPIOCGXASYNCMAP                     = 0x80207450
	PPPIOCNEWUNIT                        = 0xc004743e
	PPPIOCSACTIVE                        = 0x40087446
	PPPIOCSASYNCMAP                      = 0x40047457
	PPPIOCSCOMPRESS                      = 0x400c744d
	PPPIOCSDEBUG                         = 0x40047440
	PPPIOCSFLAGS                         = 0x40047459
	PPPIOCSMAXCID                        = 0x40047451
	PPPIOCSMRRU                          = 0x4004743b
	PPPIOCSMRU                           = 0x40047452
	PPPIOCSNPMODE                        = 0x4008744b
	PPPIOCSPASS                          = 0x40087447
	PPPIOCSRASYNCMAP                     = 0x40047454
	PPPIOCSXASYNCMAP                     = 0x4020744f
	PPPIOCXFERUNIT                       = 0x744e
	PRIO_PGRP                            = 0x1
	PRIO_PROCESS                         = 0x0
	PRIO_USER                            = 0x2
	PROC_SUPER_MAGIC                     = 0x9fa0
	PROT_EXEC                            = 0x4
	PROT_GROWSDOWN                       = 0x1000000
	PROT_GROWSUP                         = 0x2000000
	PROT_NONE                            = 0x0
	PROT_READ                            = 0x1
	PROT_WRITE                           = 0x2
	PR_CAPBSET_DROP                      = 0x18
	PR_CAPBSET_READ                      = 0x17
	PR_CAP_AMBIENT                       = 0x2f
	PR_CAP_AMBIENT_CLEAR_ALL             = 0x4
	PR_CAP_AMBIENT_IS_SET                = 0x1
	PR_CAP_AMBIENT_LOWER                 = 0x3
	PR_CAP_AMBIENT_RAISE                 = 0x2
	PR_ENDIAN_BIG                        = 0x0
	PR_ENDIAN_LITTLE                     = 0x1
	PR_ENDIAN_PPC_LITTLE                 = 0x2
	PR_FPEMU_NOPRINT                     = 0x1
	PR_FPEMU_SIGFPE                      = 0x2
	PR_FP_EXC_ASYNC                      = 0x2
	PR_FP_EXC_DISABLED                   = 0x0
	PR_FP_EXC_DIV                        = 0x10000
	PR_FP_EXC_INV                        = 0x100000
	PR_FP_EXC_NONRECOV                   = 0x1
	PR_FP_EXC_OVF                        = 0x20000
	PR_FP_EXC_PRECISE                    = 0x3
	PR_FP_EXC_RES                        = 0x80000
	PR_FP_EXC_SW_ENABLE                  = 0x80
	PR_FP_EXC_UND                        = 0x40000
	PR_FP_MODE_FR                        = 0x1
	PR_FP_MODE_FRE                       = 0x2
	PR_GET_CHILD_SUBREAPER               = 0x25
	PR_GET_DUMPABLE                      = 0x3
	PR_GET_ENDIAN                        = 0x13
	PR_GET_FPEMU                         = 0x9
	PR_GET_FPEXC                         = 0xb
	PR_GET_FP_MODE                       = 0x2e
	PR_GET_KEEPCAPS                      = 0x7
	PR_GET_NAME                          = 0x10
	PR_GET_NO_NEW_PRIVS                  = 0x27
	PR_GET_PDEATHSIG                     = 0x2
	PR_GET_SECCOMP                       = 0x15
	PR_GET_SECUREBITS                    = 0x1b
	PR_GET_SPECULATION_CTRL              = 0x34
	PR_GET_THP_DISABLE                   = 0x2a
	PR_GET_TID_ADDRESS                   = 0x28
	PR_GET_TIMERSLACK                    = 0x1e
	PR_GET_TIMING                        = 0xd
	PR_GET_TSC                           = 0x19
	PR_GET_UNALIGN                       = 0x5
	PR_MCE_KILL                          = 0x21
	PR_MCE_KILL_CLEAR                    = 0x0
	PR_MCE_KILL_DEFAULT                  = 0x2
	PR_MCE_KILL_EARLY                    = 0x1
	PR_MCE_KILL_GET                      = 0x22
	PR_MCE_KILL_LATE                     = 0x0
	PR_MCE_KILL_SET                      = 0x1
	PR_MPX_DISABLE_MANAGEMENT            = 0x2c
	PR_MPX_ENABLE_MANAGEMENT             = 0x2b
	PR_PAC_APDAKEY                       = 0x4
	PR_PAC_APDBKEY                       = 0x8
	PR_PAC_APGAKEY                       = 0x10
	PR_PAC_APIAKEY                       = 0x1
	PR_PAC_APIBKEY                       = 0x2
	PR_PAC_RESET_KEYS                    = 0x36
	PR_SET_CHILD_SUBREAPER               = 0x24
	PR_SET_DUMPABLE                      = 0x4
	PR_SET_ENDIAN                        = 0x14
	PR_SET_FPEMU                         = 0xa
	PR_SET_FPEXC                         = 0xc
	PR_SET_FP_MODE                       = 0x2d
	PR_SET_KEEPCAPS                      = 0x8
	PR_SET_MM                            = 0x23
	PR_SET_MM_ARG_END                    = 0x9
	PR_SET_MM_ARG_START                  = 0x8
	PR_SET_MM_AUXV                       = 0xc
	PR_SET_MM_BRK                        = 0x7
	PR_SET_MM_END_CODE                   = 0x2
	PR_SET_MM_END_DATA                   = 0x4
	PR_SET_MM_ENV_END                    = 0xb
	PR_SET_MM_ENV_START                  = 0xa
	PR_SET_MM_EXE_FILE                   = 0xd
	PR_SET_MM_MAP                        = 0xe
	PR_SET_MM_MAP_SIZE                   = 0xf
	PR_SET_MM_START_BRK                  = 0x6
	PR_SET_MM_START_CODE                 = 0x1
	PR_SET_MM_START_DATA                 = 0x3
	PR_SET_MM_START_STACK                = 0x5
	PR_SET_NAME                          = 0xf
	PR_SET_NO_NEW_PRIVS                  = 0x26
	PR_SET_PDEATHSIG                     = 0x1
	PR_SET_PTRACER                       = 0x59616d61
	PR_SET_PTRACER_ANY                   = 0xffffffff
	PR_SET_SECCOMP                       = 0x16
	PR_SET_SECUREBITS                    = 0x1c
	PR_SET_SPECULATION_CTRL              = 0x35
	PR_SET_THP_DISABLE                   = 0x29
	PR_SET_TIMERSLACK                    = 0x1d
	PR_SET_TIMING                        = 0xe
	PR_SET_TSC                           = 0x1a
	PR_SET_UNALIGN                       = 0x6
	PR_SPEC_DISABLE                      = 0x4
	PR_SPEC_DISABLE_NOEXEC               = 0x10
	PR_SPEC_ENABLE                       = 0x2
	PR_SPEC_FORCE_DISABLE                = 0x8
	PR_SPEC_INDIRECT_BRANCH              = 0x1
	PR_SPEC_NOT_AFFECTED                 = 0x0
	PR_SPEC_PRCTL                        = 0x1
	PR_SPEC_STORE_BYPASS                 = 0x0
	PR_SVE_GET_VL                        = 0x33
	PR_SVE_SET_VL                        = 0x32
	PR_SVE_SET_VL_ONEXEC                 = 0x40000
	PR_SVE_VL_INHERIT                    = 0x20000
	PR_SVE_VL_LEN_MASK                   = 0xffff
	PR_TASK_PERF_EVENTS_DISABLE          = 0x1f
	PR_TASK_PERF_EVENTS_ENABLE           = 0x20
	PR_TIMING_STATISTICAL                = 0x0
	PR_TIMING_TIMESTAMP                  = 0x1
	PR_TSC_ENABLE                        = 0x1
	PR_TSC_SIGSEGV                       = 0x2
	PR_UNALIGN_NOPRINT                   = 0x1
	PR_UNALIGN_SIGBUS                    = 0x2
	PSTOREFS_MAGIC                       = 0x6165676c
	PTRACE_ATTACH                        = 0x10
	PTRACE_CONT                          = 0x7
	PTRACE_DETACH                        = 0x11
	PTRACE_EVENTMSG_SYSCALL_ENTRY        = 0x1
	PTRACE_EVENTMSG_SYSCALL_EXIT         = 0x2
	PTRACE_EVENT_CLONE                   = 0x3
	PTRACE_EVENT_EXEC                    = 0x4
	PTRACE_EVENT_EXIT                    = 0x6
	PTRACE_EVENT_FORK                    = 0x1
	PTRACE_EVENT_SECCOMP                 = 0x7
	PTRACE_EVENT_STOP                    = 0x80
	PTRACE_EVENT_VFORK                   = 0x2
	PTRACE_EVENT_VFORK_DONE              = 0x5
	PTRACE_GETEVENTMSG                   = 0x4201
	PTRACE_GETFPREGS                     = 0xe
	PTRACE_GETFPXREGS                    = 0x12
	PTRACE_GETREGS                       = 0xc
	PTRACE_GETREGSET                     = 0x4204
	PTRACE_GETSIGINFO                    = 0x4202
	PTRACE_GETSIGMASK                    = 0x420a
	PTRACE_GET_SYSCALL_INFO              = 0x420e
	PTRACE_GET_THREAD_AREA               = 0x19
	PTRACE_INTERRUPT                     = 0x4207
	PTRACE_KILL                          = 0x8
	PTRACE_LISTEN                        = 0x4208
	PTRACE_OLDSETOPTIONS                 = 0x15
	PTRACE_O_EXITKILL                    = 0x100000
	PTRACE_O_MASK                        = 0x3000ff
	PTRACE_O_SUSPEND_SECCOMP             = 0x200000
	PTRACE_O_TRACECLONE                  = 0x8
	PTRACE_O_TRACEEXEC                   = 0x10
	PTRACE_O_TRACEEXIT                   = 0x40
	PTRACE_O_TRACEFORK                   = 0x2
	PTRACE_O_TRACESECCOMP                = 0x80
	PTRACE_O_TRACESYSGOOD                = 0x1
	PTRACE_O_TRACEVFORK                  = 0x4
	PTRACE_O_TRACEVFORKDONE              = 0x20
	PTRACE_PEEKDATA                      = 0x2
	PTRACE_PEEKSIGINFO                   = 0x4209
	PTRACE_PEEKSIGINFO_SHARED            = 0x1
	PTRACE_PEEKTEXT                      = 0x1
	PTRACE_PEEKUSR                       = 0x3
	PTRACE_POKEDATA                      = 0x5
	PTRACE_POKETEXT                      = 0x4
	PTRACE_POKEUSR                       = 0x6
	PTRACE_SECCOMP_GET_FILTER            = 0x420c
	PTRACE_SECCOMP_GET_METADATA          = 0x420d
	PTRACE_SEIZE                         = 0x4206
	PTRACE_SETFPREGS                     = 0xf
	PTRACE_SETFPXREGS                    = 0x13
	PTRACE_SETOPTIONS                    = 0x4200
	PTRACE_SETREGS                       = 0xd
	PTRACE_SETREGSET                     = 0x4205
	PTRACE_SETSIGINFO                    = 0x4203
	PTRACE_SETSIGMASK                    = 0x420b
	PTRACE_SET_THREAD_AREA               = 0x1a
	PTRACE_SINGLEBLOCK                   = 0x21
	PTRACE_SINGLESTEP                    = 0x9
	PTRACE_SYSCALL                       = 0x18
	PTRACE_SYSCALL_INFO_ENTRY            = 0x1
	PTRACE_SYSCALL_INFO_EXIT             = 0x2
	PTRACE_SYSCALL_INFO_NONE             = 0x0
	PTRACE_SYSCALL_INFO_SECCOMP          = 0x3
	PTRACE_SYSEMU                        = 0x1f
	PTRACE_SYSEMU_SINGLESTEP             = 0x20
	PTRACE_TRACEME                       = 0x0
	QNX4_SUPER_MAGIC                     = 0x2f
	QNX6_SUPER_MAGIC                     = 0x68191122
	RAMFS_MAGIC                          = 0x858458f6
	RDTGROUP_SUPER_MAGIC                 = 0x7655821
	REISERFS_SUPER_MAGIC                 = 0x52654973
	RENAME_EXCHANGE                      = 0x2
	RENAME_NOREPLACE                     = 0x1
	RENAME_WHITEOUT                      = 0x4
	RLIMIT_AS                            = 0x9
	RLIMIT_CORE                          = 0x4
	RLIMIT_CPU                           = 0x0
	RLIMIT_DATA                          = 0x2
	RLIMIT_FSIZE                         = 0x1
	RLIMIT_LOCKS                         = 0xa
	RLIMIT_MEMLOCK                       = 0x8
	RLIMIT_MSGQUEUE                      = 0xc
	RLIMIT_NICE                          = 0xd
	RLIMIT_NOFILE                        = 0x7
	RLIMIT_NPROC                         = 0x6
	RLIMIT_RSS                           = 0x5
	RLIMIT_RTPRIO                        = 0xe
	RLIMIT_RTTIME                        = 0xf
	RLIMIT_SIGPENDING                    = 0xb
	RLIMIT_STACK                         = 0x3
	RLIM_INFINITY                        = 0xffffffffffffffff
	RNDADDENTROPY                        = 0x40085203
	RNDADDTOENTCNT                       = 0x40045201
	RNDCLEARPOOL                         = 0x5206
	RNDGETENTCNT                         = 0x80045200
	RNDGETPOOL                           = 0x80085202
	RNDRESEEDCRNG                        = 0x5207
	RNDZAPENTCNT                         = 0x5204
	RTAX_ADVMSS                          = 0x8
	RTAX_CC_ALGO                         = 0x10
	RTAX_CWND                            = 0x7
	RTAX_FASTOPEN_NO_COOKIE              = 0x11
	RTAX_FEATURES                        = 0xc
	RTAX_FEATURE_ALLFRAG                 = 0x8
	RTAX_FEATURE_ECN                     = 0x1
	RTAX_FEATURE_MASK                    = 0xf
	RTAX_FEATURE_SACK                    = 0x2
	RTAX_FEATURE_TIMESTAMP               = 0x4
	RTAX_HOPLIMIT                        = 0xa
	RTAX_INITCWND                        = 0xb
	RTAX_INITRWND                        = 0xe
	RTAX_LOCK                            = 0x1
	RTAX_MAX                             = 0x11
	RTAX_MTU                             = 0x2
	RTAX_QUICKACK                        = 0xf
	RTAX_REORDERING                      = 0x9
	RTAX_RTO_MIN                         = 0xd
	RTAX_RTT                             = 0x4
	RTAX_RTTVAR                          = 0x5
	RTAX_SSTHRESH                        = 0x6
	RTAX_UNSPEC                          = 0x0
	RTAX_WINDOW                          = 0x3
	RTA_ALIGNTO                          = 0x4
	RTA_MAX                              = 0x1e
	RTCF_DIRECTSRC                       = 0x4000000
	RTCF_DOREDIRECT                      = 0x1000000
	RTCF_LOG                             = 0x2000000
	RTCF_MASQ                            = 0x400000
	RTCF_NAT                             = 0x800000
	RTCF_VALVE                           = 0x200000
	RTC_AF                               = 0x20
	RTC_AIE_OFF                          = 0x7002
	RTC_AIE_ON                           = 0x7001
	RTC_ALM_READ                         = 0x80247008
	RTC_ALM_SET                          = 0x40247007
	RTC_EPOCH_READ                       = 0x8004700d
	RTC_EPOCH_SET                        = 0x4004700e
	RTC_IRQF                             = 0x80
	RTC_IRQP_READ                        = 0x8004700b
	RTC_IRQP_SET                         = 0x4004700c
	RTC_MAX_FREQ                         = 0x2000
	RTC_PF                               = 0x40
	RTC_PIE_OFF                          = 0x7006
	RTC_PIE_ON                           = 0x7005
	RTC_PLL_GET                          = 0x801c7011
	RTC_PLL_SET                          = 0x401c7012
	RTC_RD_TIME                          = 0x80247009
	RTC_SET_TIME                         = 0x4024700a
	RTC_UF                               = 0x10
	RTC_UIE_OFF                          = 0x7004
	RTC_UIE_ON                           = 0x7003
	RTC_VL_CLR                           = 0x7014
	RTC_VL_READ                          = 0x80047013
	RTC_WIE_OFF                          = 0x7010
	RTC_WIE_ON                           = 0x700f
	RTC_WKALM_RD                         = 0x80287010
	RTC_WKALM_SET                        = 0x4028700f
	RTF_ADDRCLASSMASK                    = 0xf8000000
	RTF_ADDRCONF                         = 0x40000
	RTF_ALLONLINK                        = 0x20000
	RTF_BROADCAST                        = 0x10000000
	RTF_CACHE                            = 0x1000000
	RTF_DEFAULT                          = 0x10000
	RTF_DYNAMIC                          = 0x10
	RTF_FLOW                             = 0x2000000
	RTF_GATEWAY                          = 0x2
	RTF_HOST                             = 0x4
	RTF_INTERFACE                        = 0x40000000
	RTF_IRTT                             = 0x100
	RTF_LINKRT                           = 0x100000
	RTF_LOCAL                            = 0x80000000
	RTF_MODIFIED                         = 0x20
	RTF_MSS                              = 0x40
	RTF_MTU                              = 0x40
	RTF_MULTICAST                        = 0x20000000
	RTF_NAT                              = 0x8000000
	RTF_NOFORWARD                        = 0x1000
	RTF_NONEXTHOP                        = 0x200000
	RTF_NOPMTUDISC                       = 0x4000
	RTF_POLICY                           = 0x4000000
	RTF_REINSTATE                        = 0x8
	RTF_REJECT                           = 0x200
	RTF_STATIC                           = 0x400
	RTF_THROW                            = 0x2000
	RTF_UP                               = 0x1
	RTF_WINDOW                           = 0x80
	RTF_XRESOLVE                         = 0x800
	RTM_BASE                             = 0x10
	RTM_DELACTION                        = 0x31
	RTM_DELADDR                          = 0x15
	RTM_DELADDRLABEL                     = 0x49
	RTM_DELCHAIN                         = 0x65
	RTM_DELLINK                          = 0x11
	RTM_DELMDB                           = 0x55
	RTM_DELNEIGH                         = 0x1d
	RTM_DELNETCONF                       = 0x51
	RTM_DELNEXTHOP                       = 0x69
	RTM_DELNSID                          = 0x59
	RTM_DELQDISC                         = 0x25
	RTM_DELROUTE                         = 0x19
	RTM_DELRULE                          = 0x21
	RTM_DELTCLASS                        = 0x29
	RTM_DELTFILTER                       = 0x2d
	RTM_F_CLONED                         = 0x200
	RTM_F_EQUALIZE                       = 0x400
	RTM_F_FIB_MATCH                      = 0x2000
	RTM_F_LOOKUP_TABLE                   = 0x1000
	RTM_F_NOTIFY                         = 0x100
	RTM_F_PREFIX                         = 0x800
	RTM_GETACTION                        = 0x32
	RTM_GETADDR                          = 0x16
	RTM_GETADDRLABEL                     = 0x4a
	RTM_GETANYCAST                       = 0x3e
	RTM_GETCHAIN                         = 0x66
	RTM_GETDCB                           = 0x4e
	RTM_GETLINK                          = 0x12
	RTM_GETMDB                           = 0x56
	RTM_GETMULTICAST                     = 0x3a
	RTM_GETNEIGH                         = 0x1e
	RTM_GETNEIGHTBL                      = 0x42
	RTM_GETNETCONF                       = 0x52
	RTM_GETNEXTHOP                       = 0x6a
	RTM_GETNSID                          = 0x5a
	RTM_GETQDISC                         = 0x26
	RTM_GETROUTE                         = 0x1a
	RTM_GETRULE                          = 0x22
	RTM_GETSTATS                         = 0x5e
	RTM_GETTCLASS                        = 0x2a
	RTM_GETTFILTER                       = 0x2e
	RTM_MAX                              = 0x6b
	RTM_NEWACTION                        = 0x30
	RTM_NEWADDR                          = 0x14
	RTM_NEWADDRLABEL                     = 0x48
	RTM_NEWCACHEREPORT                   = 0x60
	RTM_NEWCHAIN                         = 0x64
	RTM_NEWLINK                          = 0x10
	RTM_NEWMDB                           = 0x54
	RTM_NEWNDUSEROPT                     = 0x44
	RTM_NEWNEIGH                         = 0x1c
	RTM_NEWNEIGHTBL                      = 0x40
	RTM_NEWNETCONF                       = 0x50
	RTM_NEWNEXTHOP                       = 0x68
	RTM_NEWNSID                          = 0x58
	RTM_NEWPREFIX                        = 0x34
	RTM_NEWQDISC                         = 0x24
	RTM_NEWROUTE                         = 0x18
	RTM_NEWRULE                          = 0x20
	RTM_NEWSTATS                         = 0x5c
	RTM_NEWTCLASS                        = 0x28
	RTM_NEWTFILTER                       = 0x2c
	RTM_NR_FAMILIES                      = 0x17
	RTM_NR_MSGTYPES                      = 0x5c
	RTM_SETDCB                           = 0x4f
	RTM_SETLINK                          = 0x13
	RTM_SETNEIGHTBL                      = 0x43
	RTNH_ALIGNTO                         = 0x4
	RTNH_COMPARE_MASK                    = 0x19
	RTNH_F_DEAD                          = 0x1
	RTNH_F_LINKDOWN                      = 0x10
	RTNH_F_OFFLOAD                       = 0x8
	RTNH_F_ONLINK                        = 0x4
	RTNH_F_PERVASIVE                     = 0x2
	RTNH_F_UNRESOLVED                    = 0x20
	RTN_MAX                              = 0xb
	RTPROT_BABEL                         = 0x2a
	RTPROT_BGP                           = 0xba
	RTPROT_BIRD                          = 0xc
	RTPROT_BOOT                          = 0x3
	RTPROT_DHCP                          = 0x10
	RTPROT_DNROUTED                      = 0xd
	RTPROT_EIGRP                         = 0xc0
	RTPROT_GATED                         = 0x8
	RTPROT_ISIS                          = 0xbb
	RTPROT_KERNEL                        = 0x2
	RTPROT_MROUTED                       = 0x11
	RTPROT_MRT                           = 0xa
	RTPROT_NTK                           = 0xf
	RTPROT_OSPF                          = 0xbc
	RTPROT_RA                            = 0x9
	RTPROT_REDIRECT                      = 0x1
	RTPROT_RIP                           = 0xbd
	RTPROT_STATIC                        = 0x4
	RTPROT_UNSPEC                        = 0x0
	RTPROT_XORP                          = 0xe
	RTPROT_ZEBRA                         = 0xb
	RT_CLASS_DEFAULT                     = 0xfd
	RT_CLASS_LOCAL                       = 0xff
	RT_CLASS_MAIN                        = 0xfe
	RT_CLASS_MAX                         = 0xff
	RT_CLASS_UNSPEC                      = 0x0
	RUSAGE_CHILDREN                      = -0x1
	RUSAGE_SELF                          = 0x0
	RUSAGE_THREAD                        = 0x1
	SCM_CREDENTIALS                      = 0x2
	SCM_RIGHTS                           = 0x1
	SCM_TIMESTAMP                        = 0x1d
	SCM_TIMESTAMPING                     = 0x25
	SCM_TIMESTAMPING_OPT_STATS           = 0x36
	SCM_TIMESTAMPING_PKTINFO             = 0x3a
	SCM_TIMESTAMPNS                      = 0x23
	SCM_TXTIME                           = 0x3d
	SCM_WIFI_STATUS                      = 0x29
	SC_LOG_FLUSH                         = 0x100000
	SECCOMP_MODE_DISABLED                = 0x0
	SECCOMP_MODE_FILTER                  = 0x2
	SECCOMP_MODE_STRICT                  = 0x1
	SECURITYFS_MAGIC                     = 0x73636673
	SELINUX_MAGIC                        = 0xf97cff8c
	SFD_CLOEXEC                          = 0x80000
	SFD_NONBLOCK                         = 0x800
	SHUT_RD                              = 0x0
	SHUT_RDWR                            = 0x2
	SHUT_WR                              = 0x1
	SIOCADDDLCI                          = 0x8980
	SIOCADDMULTI                         = 0x8931
	SIOCADDRT                            = 0x890b
	SIOCATMARK                           = 0x8905
	SIOCBONDCHANGEACTIVE                 = 0x8995
	SIOCBONDENSLAVE                      = 0x8990
	SIOCBONDINFOQUERY                    = 0x8994
	SIOCBONDRELEASE                      = 0x8991
	SIOCBONDSETHWADDR                    = 0x8992
	SIOCBONDSLAVEINFOQUERY               = 0x8993
	SIOCBRADDBR                          = 0x89a0
	SIOCBRADDIF                          = 0x89a2
	SIOCBRDELBR                          = 0x89a1
	SIOCBRDELIF                          = 0x89a3
	SIOCDARP                             = 0x8953
	SIOCDELDLCI                          = 0x8981
	SIOCDELMULTI                         = 0x8932
	SIOCDELRT                            = 0x890c
	SIOCDEVPRIVATE                       = 0x89f0
	SIOCDIFADDR                          = 0x8936
	SIOCDRARP                            = 0x8960
	SIOCETHTOOL                          = 0x8946
	SIOCGARP                             = 0x8954
	SIOCGETLINKNAME                      = 0x89e0
	SIOCGETNODEID                        = 0x89e1
	SIOCGHWTSTAMP                        = 0x89b1
	SIOCGIFADDR                          = 0x8915
	SIOCGIFBR                            = 0x8940
	SIOCGIFBRDADDR                       = 0x8919
	SIOCGIFCONF                          = 0x8912
	SIOCGIFCOUNT                         = 0x8938
	SIOCGIFDSTADDR                       = 0x8917
	SIOCGIFENCAP                         = 0x8925
	SIOCGIFFLAGS                         = 0x8913
	SIOCGIFHWADDR                        = 0x8927
	SIOCGIFINDEX                         = 0x8933
	SIOCGIFMAP                           = 0x8970
	SIOCGIFMEM                           = 0x891f
	SIOCGIFMETRIC                        = 0x891d
	SIOCGIFMTU                           = 0x8921
	SIOCGIFNAME                          = 0x8910
	SIOCGIFNETMASK                       = 0x891b
	SIOCGIFPFLAGS                        = 0x8935
	SIOCGIFSLAVE                         = 0x8929
	SIOCGIFTXQLEN                        = 0x8942
	SIOCGIFVLAN                          = 0x8982
	SIOCGMIIPHY                          = 0x8947
	SIOCGMIIREG                          = 0x8948
	SIOCGPGRP                            = 0x8904
	SIOCGPPPCSTATS                       = 0x89f2
	SIOCGPPPSTATS                        = 0x89f0
	SIOCGPPPVER                          = 0x89f1
	SIOCGRARP                            = 0x8961
	SIOCGSKNS                            = 0x894c
	SIOCGSTAMP                           = 0x8906
	SIOCGSTAMPNS                         = 0x8907
	SIOCGSTAMPNS_NEW                     = 0x80108907
	SIOCGSTAMPNS_OLD                     = 0x8907
	SIOCGSTAMP_NEW                       = 0x80108906
	SIOCGSTAMP_OLD                       = 0x8906
	SIOCINQ                              = 0x541b
	SIOCOUTQ                             = 0x5411
	SIOCOUTQNSD                          = 0x894b
	SIOCPROTOPRIVATE                     = 0x89e0
	SIOCRTMSG                            = 0x890d
	SIOCSARP                             = 0x8955
	SIOCSHWTSTAMP                        = 0x89b0
	SIOCSIFADDR                          = 0x8916
	SIOCSIFBR                            = 0x8941
	SIOCSIFBRDADDR                       = 0x891a
	SIOCSIFDSTADDR                       = 0x8918
	SIOCSIFENCAP                         = 0x8926
	SIOCSIFFLAGS                         = 0x8914
	SIOCSIFHWADDR                        = 0x8924
	SIOCSIFHWBROADCAST                   = 0x8937
	SIOCSIFLINK                          = 0x8911
	SIOCSIFMAP                           = 0x8971
	SIOCSIFMEM                           = 0x8920
	SIOCSIFMETRIC                        = 0x891e
	SIOCSIFMTU                           = 0x8922
	SIOCSIFNAME                          = 0x8923
	SIOCSIFNETMASK                       = 0x891c
	SIOCSIFPFLAGS                        = 0x8934
	SIOCSIFSLAVE                         = 0x8930
	SIOCSIFTXQLEN                        = 0x8943
	SIOCSIFVLAN                          = 0x8983
	SIOCSMIIREG                          = 0x8949
	SIOCSPGRP                            = 0x8902
	SIOCSRARP                            = 0x8962
	SIOCWANDEV                           = 0x894a
	SMACK_MAGIC                          = 0x43415d53
	SMART_AUTOSAVE                       = 0xd2
	SMART_AUTO_OFFLINE                   = 0xdb
	SMART_DISABLE                        = 0xd9
	SMART_ENABLE                         = 0xd8
	SMART_HCYL_PASS                      = 0xc2
	SMART_IMMEDIATE_OFFLINE              = 0xd4
	SMART_LCYL_PASS                      = 0x4f
	SMART_READ_LOG_SECTOR                = 0xd5
	SMART_READ_THRESHOLDS                = 0xd1
	SMART_READ_VALUES                    = 0xd0
	SMART_SAVE                           = 0xd3
	SMART_STATUS                         = 0xda
	SMART_WRITE_LOG_SECTOR               = 0xd6
	SMART_WRITE_THRESHOLDS               = 0xd7
	SMB_SUPER_MAGIC                      = 0x517b
	SOCKFS_MAGIC                         = 0x534f434b
	SOCK_CLOEXEC                         = 0x80000
	SOCK_DCCP                            = 0x6
	SOCK_DGRAM                           = 0x2
	SOCK_IOC_TYPE                        = 0x89
	SOCK_NONBLOCK                        = 0x800
	SOCK_PACKET                          = 0xa
	SOCK_RAW                             = 0x3
	SOCK_RDM                             = 0x4
	SOCK_SEQPACKET                       = 0x5
	SOCK_STREAM                          = 0x1
	SOL_AAL                              = 0x109
	SOL_ALG                              = 0x117
	SOL_ATM                              = 0x108
	SOL_CAIF                             = 0x116
	SOL_CAN_BASE                         = 0x64
	SOL_DCCP                             = 0x10d
	SOL_DECNET                           = 0x105
	SOL_ICMPV6                           = 0x3a
	SOL_IP                               = 0x0
	SOL_IPV6                             = 0x29
	SOL_IRDA                             = 0x10a
	SOL_IUCV                             = 0x115
	SOL_KCM                              = 0x119
	SOL_LLC                              = 0x10c
	SOL_NETBEUI                          = 0x10b
	SOL_NETLINK                          = 0x10e
	SOL_NFC                              = 0x118
	SOL_PACKET                           = 0x107
	SOL_PNPIPE                           = 0x113
	SOL_PPPOL2TP                         = 0x111
	SOL_RAW                              = 0xff
	SOL_RDS                              = 0x114
	SOL_RXRPC                            = 0x110
	SOL_SOCKET                           = 0x1
	SOL_TCP                              = 0x6
	SOL_TIPC                             = 0x10f
	SOL_TLS                              = 0x11a
	SOL_X25                              = 0x106
	SOL_XDP                              = 0x11b
	SOMAXCONN                            = 0x80
	SO_ACCEPTCONN                        = 0x1e
	SO_ATTACH_BPF                        = 0x32
	SO_ATTACH_FILTER                     = 0x1a
	SO_ATTACH_REUSEPORT_CBPF             = 0x33
	SO_ATTACH_REUSEPORT_EBPF             = 0x34
	SO_BINDTODEVICE                      = 0x19
	SO_BINDTOIFINDEX                     = 0x3e
	SO_BPF_EXTENSIONS                    = 0x30
	SO_BROADCAST                         = 0x6
	SO_BSDCOMPAT                         = 0xe
	SO_BUSY_POLL                         = 0x2e
	SO_CNX_ADVICE                        = 0x35
	SO_COOKIE                            = 0x39
	SO_DEBUG                             = 0x1
	SO_DETACH_BPF                        = 0x1b
	SO_DETACH_FILTER                     = 0x1b
	SO_DETACH_REUSEPORT_BPF              = 0x44
	SO_DOMAIN                            = 0x27
	SO_DONTROUTE                         = 0x5
	SO_EE_CODE_TXTIME_INVALID_PARAM      = 0x1
	SO_EE_CODE_TXTIME_MISSED             = 0x2
	SO_EE_CODE_ZEROCOPY_COPIED           = 0x1
	SO_EE_ORIGIN_ICMP                    = 0x2
	SO_EE_ORIGIN_ICMP6                   = 0x3
	SO_EE_ORIGIN_LOCAL                   = 0x1
	SO_EE_ORIGIN_NONE                    = 0x0
	SO_EE_ORIGIN_TIMESTAMPING            = 0x4
	SO_EE_ORIGIN_TXSTATUS                = 0x4
	SO_EE_ORIGIN_TXTIME                  = 0x6
	SO_EE_ORIGIN_ZEROCOPY                = 0x5
	SO_ERROR                             = 0x4
	SO_GET_FILTER                        = 0x1a
	SO_INCOMING_CPU                      = 0x31
	SO_INCOMING_NAPI_ID                  = 0x38
	SO_KEEPALIVE                         = 0x9
	SO_LINGER                            = 0xd
	SO_LOCK_FILTER                       = 0x2c
	SO_MARK                              = 0x24
	SO_MAX_PACING_RATE                   = 0x2f
	SO_MEMINFO                           = 0x37
	SO_NOFCS                             = 0x2b
	SO_NO_CHECK                          = 0xb
	SO_OOBINLINE                         = 0xa
	SO_PASSCRED                          = 0x10
	SO_PASSSEC                           = 0x22
	SO_PEEK_OFF                          = 0x2a
	SO_PEERCRED                          = 0x11
	SO_PEERGROUPS                        = 0x3b
	SO_PEERNAME                          = 0x1c
	SO_PEERSEC                           = 0x1f
	SO_PRIORITY                          = 0xc
	SO_PROTOCOL                          = 0x26
	SO_RCVBUF                            = 0x8
	SO_RCVBUFFORCE                       = 0x21
	SO_RCVLOWAT                          = 0x12
	SO_RCVTIMEO                          = 0x14
	SO_RCVTIMEO_NEW                      = 0x42
	SO_RCVTIMEO_OLD                      = 0x14
	SO_REUSEADDR                         = 0x2
	SO_REUSEPORT                         = 0xf
	SO_RXQ_OVFL                          = 0x28
	SO_SECURITY_AUTHENTICATION           = 0x16
	SO_SECURITY_ENCRYPTION_NETWORK       = 0x18
	SO_SECURITY_ENCRYPTION_TRANSPORT     = 0x17
	SO_SELECT_ERR_QUEUE                  = 0x2d
	SO_SNDBUF                            = 0x7
	SO_SNDBUFFORCE                       = 0x20
	SO_SNDLOWAT                          = 0x13
	SO_SNDTIMEO                          = 0x15
	SO_SNDTIMEO_NEW                      = 0x43
	SO_SNDTIMEO_OLD                      = 0x15
	SO_TIMESTAMP                         = 0x1d
	SO_TIMESTAMPING                      = 0x25
	SO_TIMESTAMPING_NEW                  = 0x41
	SO_TIMESTAMPING_OLD                  = 0x25
	SO_TIMESTAMPNS                       = 0x23
	SO_TIMESTAMPNS_NEW                   = 0x40
	SO_TIMESTAMPNS_OLD                   = 0x23
	SO_TIMESTAMP_NEW                     = 0x3f
	SO_TIMESTAMP_OLD                     = 0x1d
	SO_TXTIME                            = 0x3d
	SO_TYPE                              = 0x3
	SO_VM_SOCKETS_BUFFER_MAX_SIZE        = 0x2
	SO_VM_SOCKETS_BUFFER_MIN_SIZE        = 0x1
	SO_VM_SOCKETS_BUFFER_SIZE            = 0x0
	SO_VM_SOCKETS_CONNECT_TIMEOUT        = 0x6
	SO_VM_SOCKETS_NONBLOCK_TXRX          = 0x7
	SO_VM_SOCKETS_PEER_HOST_VM_ID        = 0x3
	SO_VM_SOCKETS_TRUSTED                = 0x5
	SO_WIFI_STATUS                       = 0x29
	SO_ZEROCOPY                          = 0x3c
	SPLICE_F_GIFT                        = 0x8
	SPLICE_F_MORE                        = 0x4
	SPLICE_F_MOVE                        = 0x1
	SPLICE_F_NONBLOCK                    = 0x2
	SQUASHFS_MAGIC                       = 0x73717368
	STACK_END_MAGIC                      = 0x57ac6e9d
	STATX_ALL                            = 0xfff
	STATX_ATIME                          = 0x20
	STATX_ATTR_APPEND                    = 0x20
	STATX_ATTR_AUTOMOUNT                 = 0x1000
	STATX_ATTR_COMPRESSED                = 0x4
	STATX_ATTR_ENCRYPTED                 = 0x800
	STATX_ATTR_IMMUTABLE                 = 0x10
	STATX_ATTR_NODUMP                    = 0x40
	STATX_BASIC_STATS                    = 0x7ff
	STATX_BLOCKS                         = 0x400
	STATX_BTIME                          = 0x800
	STATX_CTIME                          = 0x80
	STATX_GID                            = 0x10
	STATX_INO                            = 0x100
	STATX_MODE                           = 0x2
	STATX_MTIME                          = 0x40
	STATX_NLINK                          = 0x4
	STATX_SIZE                           = 0x200
	STATX_TYPE                           = 0x1
	STATX_UID                            = 0x8
	STATX__RESERVED                      = 0x80000000
	SYNC_FILE_RANGE_WAIT_AFTER           = 0x4
	SYNC_FILE_RANGE_WAIT_BEFORE          = 0x1
	SYNC_FILE_RANGE_WRITE                = 0x2
	SYNC_FILE_RANGE_WRITE_AND_WAIT       = 0x7
	SYSFS_MAGIC                          = 0x62656572
	S_BLKSIZE                            = 0x200
	S_IEXEC                              = 0x40
	S_IFBLK                              = 0x6000
	S_IFCHR                              = 0x2000
	S_IFDIR                              = 0x4000
	S_IFIFO                              = 0x1000
	S_IFLNK                              = 0xa000
	S_IFMT                               = 0xf000
	S_IFREG                              = 0x8000
	S_IFSOCK                             = 0xc000
	S_IREAD                              = 0x100
	S_IRGRP                              = 0x20
	S_IROTH                              = 0x4
	S_IRUSR                              = 0x100
	S_IRWXG                              = 0x38
	S_IRWXO                              = 0x7
	S_IRWXU                              = 0x1c0
	S_ISGID                              = 0x400
	S_ISUID                              = 0x800
	S_ISVTX                              = 0x200
	S_IWGRP                              = 0x10
	S_IWOTH                              = 0x2
	S_IWRITE                             = 0x80
	S_IWUSR                              = 0x80
	S_IXGRP                              = 0x8
	S_IXOTH                              = 0x1
	S_IXUSR                              = 0x40
	TAB0                                 = 0x0
	TAB1                                 = 0x800
	TAB2                                 = 0x1000
	TAB3                                 = 0x1800
	TABDLY                               = 0x1800
	TASKSTATS_CMD_ATTR_MAX               = 0x4
	TASKSTATS_CMD_MAX                    = 0x2
	TASKSTATS_GENL_NAME                  = "TASKSTATS"
	TASKSTATS_GENL_VERSION               = 0x1
	TASKSTATS_TYPE_MAX                   = 0x6
	TASKSTATS_VERSION                    = 0x9
	TCFLSH                               = 0x540b
	TCGETA                               = 0x5405
	TCGETS                               = 0x5401
	TCGETS2                              = 0x802c542a
	TCGETX                               = 0x5432
	TCIFLUSH                             = 0x0
	TCIOFF                               = 0x2
	TCIOFLUSH                            = 0x2
	TCION                                = 0x3
	TCOFLUSH                             = 0x1
	TCOOFF                               = 0x0
	TCOON                                = 0x1
	TCP_BPF_IW                           = 0x3e9
	TCP_BPF_SNDCWND_CLAMP                = 0x3ea
	TCP_CC_INFO                          = 0x1a
	TCP_CM_INQ                           = 0x24
	TCP_CONGESTION                       = 0xd
	TCP_COOKIE_IN_ALWAYS                 = 0x1
	TCP_COOKIE_MAX                       = 0x10
	TCP_COOKIE_MIN                       = 0x8
	TCP_COOKIE_OUT_NEVER                 = 0x2
	TCP_COOKIE_PAIR_SIZE                 = 0x20
	TCP_COOKIE_TRANSACTIONS              = 0xf
	TCP_CORK                             = 0x3
	TCP_DEFER_ACCEPT                     = 0x9
	TCP_FASTOPEN                         = 0x17
	TCP_FASTOPEN_CONNECT                 = 0x1e
	TCP_FASTOPEN_KEY                     = 0x21
	TCP_FASTOPEN_NO_COOKIE               = 0x22
	TCP_INFO                             = 0xb
	TCP_INQ                              = 0x24
	TCP_KEEPCNT                          = 0x6
	TCP_KEEPIDLE                         = 0x4
	TCP_KEEPINTVL                        = 0x5
	TCP_LINGER2                          = 0x8
	TCP_MAXSEG                           = 0x2
	TCP_MAXWIN                           = 0xffff
	TCP_MAX_WINSHIFT                     = 0xe
	TCP_MD5SIG                           = 0xe
	TCP_MD5SIG_EXT                       = 0x20
	TCP_MD5SIG_FLAG_PREFIX               = 0x1
	TCP_MD5SIG_MAXKEYLEN                 = 0x50
	TCP_MSS                              = 0x200
	TCP_MSS_DEFAULT                      = 0x218
	TCP_MSS_DESIRED                      = 0x4c4
	TCP_NODELAY                          = 0x1
	TCP_NOTSENT_LOWAT                    = 0x19
	TCP_QUEUE_SEQ                        = 0x15
	TCP_QUICKACK                         = 0xc
	TCP_REPAIR                           = 0x13
	TCP_REPAIR_OFF                       = 0x0
	TCP_REPAIR_OFF_NO_WP                 = -0x1
	TCP_REPAIR_ON                        = 0x1
	TCP_REPAIR_OPTIONS                   = 0x16
	TCP_REPAIR_QUEUE                     = 0x14
	TCP_REPAIR_WINDOW                    = 0x1d
	TCP_SAVED_SYN                        = 0x1c
	TCP_SAVE_SYN                         = 0x1b
	TCP_SYNCNT                           = 0x7
	TCP_S_DATA_IN                        = 0x4
	TCP_S_DATA_OUT                       = 0x8
	TCP_THIN_DUPACK                      = 0x11
	TCP_THIN_LINEAR_TIMEOUTS             = 0x10
	TCP_TIMESTAMP                        = 0x18
	TCP_ULP                              = 0x1f
	TCP_USER_TIMEOUT                     = 0x12
	TCP_WINDOW_CLAMP                     = 0xa
	TCP_ZEROCOPY_RECEIVE                 = 0x23
	TCSAFLUSH                            = 0x2
	TCSBRK                               = 0x5409
	TCSBRKP                              = 0x5425
	TCSETA                               = 0x5406
	TCSETAF                              = 0x5408
	TCSETAW                              = 0x5407
	TCSETS                               = 0x5402
	TCSETS2                              = 0x402c542b
	TCSETSF                              = 0x5404
	TCSETSF2                             = 0x402c542d
	TCSETSW                              = 0x5403
	TCSETSW2                             = 0x402c542c
	TCSETX                               = 0x5433
	TCSETXF                              = 0x5434
	TCSETXW                              = 0x5435
	TCXONC                               = 0x540a
	TIMER_ABSTIME                        = 0x1
	TIOCCBRK                             = 0x5428
	TIOCCONS                             = 0x541d
	TIOCEXCL                             = 0x540c
	TIOCGDEV                             = 0x80045432
	TIOCGETD                             = 0x5424
	TIOCGEXCL                            = 0x80045440
	TIOCGICOUNT                          = 0x545d
	TIOCGISO7816                         = 0x80285442
	TIOCGLCKTRMIOS                       = 0x5456
	TIOCGPGRP                            = 0x540f
	TIOCGPKT                             = 0x80045438
	TIOCGPTLCK                           = 0x80045439
	TIOCGPTN                             = 0x80045430
	TIOCGPTPEER                          = 0x5441
	TIOCGRS485                           = 0x542e
	TIOCGSERIAL                          = 0x541e
	TIOCGSID                             = 0x5429
	TIOCGSOFTCAR                         = 0x5419
	TIOCGWINSZ                           = 0x5413
	TIOCINQ                              = 0x541b
	TIOCLINUX                            = 0x541c
	TIOCMBIC                             = 0x5417
	TIOCMBIS                             = 0x5416
	TIOCMGET                             = 0x5415
	TIOCMIWAIT                           = 0x545c
	TIOCMSET                             = 0x5418
	TIOCM_CAR                            = 0x40
	TIOCM_CD                             = 0x40
	TIOCM_CTS                            = 0x20
	TIOCM_DSR                            = 0x100
	TIOCM_DTR                            = 0x2
	TIOCM_LE                             = 0x1
	TIOCM_RI                             = 0x80
	TIOCM_RNG                            = 0x80
	TIOCM_RTS                            = 0x4
	TIOCM_SR                             = 0x10
	TIOCM_ST                             = 0x8
	TIOCNOTTY                            = 0x5422
	TIOCNXCL                             = 0x540d
	TIOCOUTQ                             = 0x5411
	TIOCPKT                              = 0x5420
	TIOCPKT_DATA                         = 0x0
	TIOCPKT_DOSTOP                       = 0x20
	TIOCPKT_FLUSHREAD                    = 0x1
	TIOCPKT_FLUSHWRITE                   = 0x2
	TIOCPKT_IOCTL                        = 0x40
	TIOCPKT_NOSTOP                       = 0x10
	TIOCPKT_START                        = 0x8
	TIOCPKT_STOP                         = 0x4
	TIOCSBRK                             = 0x5427
	TIOCSCTTY                            = 0x540e
	TIOCSERCONFIG                        = 0x5453
	TIOCSERGETLSR                        = 0x5459
	TIOCSERGETMULTI                      = 0x545a
	TIOCSERGSTRUCT                       = 0x5458
	TIOCSERGWILD                         = 0x5454
	TIOCSERSETMULTI                      = 0x545b
	TIOCSERSWILD                         = 0x5455
	TIOCSER_TEMT                         = 0x1
	TIOCSETD                             = 0x5423
	TIOCSIG                              = 0x40045436
	TIOCSISO7816                         = 0xc0285443
	TIOCSLCKTRMIOS                       = 0x5457
	TIOCSPGRP                            = 0x5410
	TIOCSPTLCK                           = 0x40045431
	TIOCSRS485                           = 0x542f
	TIOCSSERIAL                          = 0x541f
	TIOCSSOFTCAR                         = 0x541a
	TIOCSTI                              = 0x5412
	TIOCSWINSZ                           = 0x5414
	TIOCVHANGUP                          = 0x5437
	TIPC_ADDR_ID                         = 0x3
	TIPC_ADDR_MCAST                      = 0x1
	TIPC_ADDR_NAME                       = 0x2
	TIPC_ADDR_NAMESEQ                    = 0x1
	TIPC_CFG_SRV                         = 0x0
	TIPC_CLUSTER_BITS                    = 0xc
	TIPC_CLUSTER_MASK                    = 0xfff000
	TIPC_CLUSTER_OFFSET                  = 0xc
	TIPC_CLUSTER_SIZE                    = 0xfff
	TIPC_CONN_SHUTDOWN                   = 0x5
	TIPC_CONN_TIMEOUT                    = 0x82
	TIPC_CRITICAL_IMPORTANCE             = 0x3
	TIPC_DESTNAME                        = 0x3
	TIPC_DEST_DROPPABLE                  = 0x81
	TIPC_ERRINFO                         = 0x1
	TIPC_ERR_NO_NAME                     = 0x1
	TIPC_ERR_NO_NODE                     = 0x3
	TIPC_ERR_NO_PORT                     = 0x2
	TIPC_ERR_OVERLOAD                    = 0x4
	TIPC_GROUP_JOIN                      = 0x87
	TIPC_GROUP_LEAVE                     = 0x88
	TIPC_GROUP_LOOPBACK                  = 0x1
	TIPC_GROUP_MEMBER_EVTS               = 0x2
	TIPC_HIGH_IMPORTANCE                 = 0x2
	TIPC_IMPORTANCE                      = 0x7f
	TIPC_LINK_STATE                      = 0x2
	TIPC_LOW_IMPORTANCE                  = 0x0
	TIPC_MAX_BEARER_NAME                 = 0x20
	TIPC_MAX_IF_NAME                     = 0x10
	TIPC_MAX_LINK_NAME                   = 0x44
	TIPC_MAX_MEDIA_NAME                  = 0x10
	TIPC_MAX_USER_MSG_SIZE               = 0x101d0
	TIPC_MCAST_BROADCAST                 = 0x85
	TIPC_MCAST_REPLICAST                 = 0x86
	TIPC_MEDIUM_IMPORTANCE               = 0x1
	TIPC_NODEID_LEN                      = 0x10
	TIPC_NODE_BITS                       = 0xc
	TIPC_NODE_MASK                       = 0xfff
	TIPC_NODE_OFFSET                     = 0x0
	TIPC_NODE_RECVQ_DEPTH                = 0x83
	TIPC_NODE_SIZE                       = 0xfff
	TIPC_NODE_STATE                      = 0x0
	TIPC_OK                              = 0x0
	TIPC_PUBLISHED                       = 0x1
	TIPC_RESERVED_TYPES                  = 0x40
	TIPC_RETDATA                         = 0x2
	TIPC_SERVICE_ADDR                    = 0x2
	TIPC_SERVICE_RANGE                   = 0x1
	TIPC_SOCKET_ADDR                     = 0x3
	TIPC_SOCK_RECVQ_DEPTH                = 0x84
	TIPC_SOCK_RECVQ_USED                 = 0x89
	TIPC_SRC_DROPPABLE                   = 0x80
	TIPC_SUBSCR_TIMEOUT                  = 0x3
	TIPC_SUB_CANCEL                      = 0x4
	TIPC_SUB_PORTS                       = 0x1
	TIPC_SUB_SERVICE                     = 0x2
	TIPC_TOP_SRV                         = 0x1
	TIPC_WAIT_FOREVER                    = 0xffffffff
	TIPC_WITHDRAWN                       = 0x2
	TIPC_ZONE_BITS                       = 0x8
	TIPC_ZONE_CLUSTER_MASK               = 0xfffff000
	TIPC_ZONE_MASK                       = 0xff000000
	TIPC_ZONE_OFFSET                     = 0x18
	TIPC_ZONE_SCOPE                      = 0x1
	TIPC_ZONE_SIZE                       = 0xff
	TMPFS_MAGIC                          = 0x1021994
	TOSTOP                               = 0x100
	TPACKET_ALIGNMENT                    = 0x10
	TPACKET_HDRLEN                       = 0x34
	TP_STATUS_AVAILABLE                  = 0x0
	TP_STATUS_BLK_TMO                    = 0x20
	TP_STATUS_COPY                       = 0x2
	TP_STATUS_CSUMNOTREADY               = 0x8
	TP_STATUS_CSUM_VALID                 = 0x80
	TP_STATUS_KERNEL                     = 0x0
	TP_STATUS_LOSING                     = 0x4
	TP_STATUS_SENDING                    = 0x2
	TP_STATUS_SEND_REQUEST               = 0x1
	TP_STATUS_TS_RAW_HARDWARE            = 0x80000000
	TP_STATUS_TS_SOFTWARE                = 0x20000000
	TP_STATUS_TS_SYS_HARDWARE            = 0x40000000
	TP_STATUS_USER                       = 0x1
	TP_STATUS_VLAN_TPID_VALID            = 0x40
	TP_STATUS_VLAN_VALID                 = 0x10
	TP_STATUS_WRONG_FORMAT               = 0x4
	TRACEFS_MAGIC                        = 0x74726163
	TS_COMM_LEN                          = 0x20
	TUNATTACHFILTER                      = 0x400854d5
	TUNDETACHFILTER                      = 0x400854d6
	TUNGETDEVNETNS                       = 0x54e3
	TUNGETFEATURES                       = 0x800454cf
	TUNGETFILTER                         = 0x800854db
	TUNGETIFF                            = 0x800454d2
	TUNGETSNDBUF                         = 0x800454d3
	TUNGETVNETBE                         = 0x800454df
	TUNGETVNETHDRSZ                      = 0x800454d7
	TUNGETVNETLE                         = 0x800454dd
	TUNSETCARRIER                        = 0x400454e2
	TUNSETDEBUG                          = 0x400454c9
	TUNSETFILTEREBPF                     = 0x800454e1
	TUNSETGROUP                          = 0x400454ce
	TUNSETIFF                            = 0x400454ca
	TUNSETIFINDEX                        = 0x400454da
	TUNSETLINK                           = 0x400454cd
	TUNSETNOCSUM                         = 0x400454c8
	TUNSETOFFLOAD                        = 0x400454d0
	TUNSETOWNER                          = 0x400454cc
	TUNSETPERSIST                        = 0x400454cb
	TUNSETQUEUE                          = 0x400454d9
	TUNSETSNDBUF                         = 0x400454d4
	TUNSETSTEERINGEBPF                   = 0x800454e0
	TUNSETTXFILTER                       = 0x400454d1
	TUNSETVNETBE                         = 0x400454de
	TUNSETVNETHDRSZ                      = 0x400454d8
	TUNSETVNETLE                         = 0x400454dc
	UBI_IOCATT                           = 0x40186f40
	UBI_IOCDET                           = 0x40046f41
	UBI_IOCEBCH                          = 0x40044f02
	UBI_IOCEBER                          = 0x40044f01
	UBI_IOCEBISMAP                       = 0x80044f05
	UBI_IOCEBMAP                         = 0x40084f03
	UBI_IOCEBUNMAP                       = 0x40044f04
	UBI_IOCMKVOL                         = 0x40986f00
	UBI_IOCRMVOL                         = 0x40046f01
	UBI_IOCRNVOL                         = 0x51106f03
	UBI_IOCRPEB                          = 0x40046f04
	UBI_IOCRSVOL                         = 0x400c6f02
	UBI_IOCSETVOLPROP                    = 0x40104f06
	UBI_IOCSPEB                          = 0x40046f05
	UBI_IOCVOLCRBLK                      = 0x40804f07
	UBI_IOCVOLRMBLK                      = 0x4f08
	UBI_IOCVOLUP                         = 0x40084f00
	UDF_SUPER_MAGIC                      = 0x15013346
	UMOUNT_NOFOLLOW                      = 0x8
	USBDEVICE_SUPER_MAGIC                = 0x9fa2
	UTIME_NOW                            = 0x3fffffff
	UTIME_OMIT                           = 0x3ffffffe
	V9FS_MAGIC                           = 0x1021997
	VDISCARD                             = 0xd
	VEOF                                 = 0x4
	VEOL                                 = 0xb
	VEOL2                                = 0x10
	VERASE                               = 0x2
	VINTR                                = 0x0
	VKILL                                = 0x3
	VLNEXT                               = 0xf
	VMADDR_CID_ANY                       = 0xffffffff
	VMADDR_CID_HOST                      = 0x2
	VMADDR_CID_HYPERVISOR                = 0x0
	VMADDR_CID_RESERVED                  = 0x1
	VMADDR_PORT_ANY                      = 0xffffffff
	VMIN                                 = 0x6
	VM_SOCKETS_INVALID_VERSION           = 0xffffffff
	VQUIT                                = 0x1
	VREPRINT                             = 0xc
	VSTART                               = 0x8
	VSTOP                                = 0x9
	VSUSP                                = 0xa
	VSWTC                                = 0x7
	VT0                                  = 0x0
	VT1                                  = 0x4000
	VTDLY                                = 0x4000
	VTIME                                = 0x5
	VWERASE                              = 0xe
	WALL                                 = 0x40000000
	WCLONE                               = 0x80000000
	WCONTINUED                           = 0x8
	WDIOC_GETBOOTSTATUS                  = 0x80045702
	WDIOC_GETPRETIMEOUT                  = 0x80045709
	WDIOC_GETSTATUS                      = 0x80045701
	WDIOC_GETSUPPORT                     = 0x80285700
	WDIOC_GETTEMP                        = 0x80045703
	WDIOC_GETTIMELEFT                    = 0x8004570a
	WDIOC_GETTIMEOUT                     = 0x80045707
	WDIOC_KEEPALIVE                      = 0x80045705
	WDIOC_SETOPTIONS                     = 0x80045704
	WDIOC_SETPRETIMEOUT                  = 0xc0045708
	WDIOC_SETTIMEOUT                     = 0xc0045706
	WEXITED                              = 0x4
	WIN_ACKMEDIACHANGE                   = 0xdb
	WIN_CHECKPOWERMODE1                  = 0xe5
	WIN_CHECKPOWERMODE2                  = 0x98
	WIN_DEVICE_RESET                     = 0x8
	WIN_DIAGNOSE                         = 0x90
	WIN_DOORLOCK                         = 0xde
	WIN_DOORUNLOCK                       = 0xdf
	WIN_DOWNLOAD_MICROCODE               = 0x92
	WIN_FLUSH_CACHE                      = 0xe7
	WIN_FLUSH_CACHE_EXT                  = 0xea
	WIN_FORMAT                           = 0x50
	WIN_GETMEDIASTATUS                   = 0xda
	WIN_IDENTIFY                         = 0xec
	WIN_IDENTIFY_DMA                     = 0xee
	WIN_IDLEIMMEDIATE                    = 0xe1
	WIN_INIT                             = 0x60
	WIN_MEDIAEJECT                       = 0xed
	WIN_MULTREAD                         = 0xc4
	WIN_MULTREAD_EXT                     = 0x29
	WIN_MULTWRITE                        = 0xc5
	WIN_MULTWRITE_EXT                    = 0x39
	WIN_NOP                              = 0x0
	WIN_PACKETCMD                        = 0xa0
	WIN_PIDENTIFY                        = 0xa1
	WIN_POSTBOOT                         = 0xdc
	WIN_PREBOOT                          = 0xdd
	WIN_QUEUED_SERVICE                   = 0xa2
	WIN_READ                             = 0x20
	WIN_READDMA                          = 0xc8
	WIN_READDMA_EXT                      = 0x25
	WIN_READDMA_ONCE                     = 0xc9
	WIN_READDMA_QUEUED                   = 0xc7
	WIN_READDMA_QUEUED_EXT               = 0x26
	WIN_READ_BUFFER                      = 0xe4
	WIN_READ_EXT                         = 0x24
	WIN_READ_LONG                        = 0x22
	WIN_READ_LONG_ONCE                   = 0x23
	WIN_READ_NATIVE_MAX                  = 0xf8
	WIN_READ_NATIVE_MAX_EXT              = 0x27
	WIN_READ_ONCE                        = 0x21
	WIN_RECAL                            = 0x10
	WIN_RESTORE                          = 0x10
	WIN_SECURITY_DISABLE                 = 0xf6
	WIN_SECURITY_ERASE_PREPARE           = 0xf3
	WIN_SECURITY_ERASE_UNIT              = 0xf4
	WIN_SECURITY_FREEZE_LOCK             = 0xf5
	WIN_SECURITY_SET_PASS                = 0xf1
	WIN_SECURITY_UNLOCK                  = 0xf2
	WIN_SEEK                             = 0x70
	WIN_SETFEATURES                      = 0xef
	WIN_SETIDLE1                         = 0xe3
	WIN_SETIDLE2                         = 0x97
	WIN_SETMULT                          = 0xc6
	WIN_SET_MAX                          = 0xf9
	WIN_SET_MAX_EXT                      = 0x37
	WIN_SLEEPNOW1                        = 0xe6
	WIN_SLEEPNOW2                        = 0x99
	WIN_SMART                            = 0xb0
	WIN_SPECIFY                          = 0x91
	WIN_SRST                             = 0x8
	WIN_STANDBY                          = 0xe2
	WIN_STANDBY2                         = 0x96
	WIN_STANDBYNOW1                      = 0xe0
	WIN_STANDBYNOW2                      = 0x94
	WIN_VERIFY                           = 0x40
	WIN_VERIFY_EXT                       = 0x42
	WIN_VERIFY_ONCE                      = 0x41
	WIN_WRITE                            = 0x30
	WIN_WRITEDMA                         = 0xca
	WIN_WRITEDMA_EXT                     = 0x35
	WIN_WRITEDMA_ONCE                    = 0xcb
	WIN_WRITEDMA_QUEUED                  = 0xcc
	WIN_WRITEDMA_QUEUED_EXT              = 0x36
	WIN_WRITE_BUFFER                     = 0xe8
	WIN_WRITE_EXT                        = 0x34
	WIN_WRITE_LONG                       = 0x32
	WIN_WRITE_LONG_ONCE                  = 0x33
	WIN_WRITE_ONCE                       = 0x31
	WIN_WRITE_SAME                       = 0xe9
	WIN_WRITE_VERIFY                     = 0x3c
	WNOHANG                              = 0x1
	WNOTHREAD                            = 0x20000000
	WNOWAIT                              = 0x1000000
	WORDSIZE                             = 0x20
	WSTOPPED                             = 0x2
	WUNTRACED                            = 0x2
	X86_FXSR_MAGIC                       = 0x0
	XATTR_CREATE                         = 0x1
	XATTR_REPLACE                        = 0x2
	XCASE                                = 0x4
	XDP_COPY                             = 0x2
	XDP_FLAGS_DRV_MODE                   = 0x4
	XDP_FLAGS_HW_MODE                    = 0x8
	XDP_FLAGS_MASK                       = 0xf
	XDP_FLAGS_MODES                      = 0xe
	XDP_FLAGS_SKB_MODE                   = 0x2
	XDP_FLAGS_UPDATE_IF_NOEXIST          = 0x1
	XDP_MMAP_OFFSETS                     = 0x1
	XDP_OPTIONS                          = 0x8
	XDP_OPTIONS_ZEROCOPY                 = 0x1
	XDP_PACKET_HEADROOM                  = 0x100
	XDP_PGOFF_RX_RING                    = 0x0
	XDP_PGOFF_TX_RING                    = 0x80000000
	XDP_RX_RING                          = 0x2
	XDP_SHARED_UMEM                      = 0x1
	XDP_STATISTICS                       = 0x7
	XDP_TX_RING                          = 0x3
	XDP_UMEM_COMPLETION_RING             = 0x6
	XDP_UMEM_FILL_RING                   = 0x5
	XDP_UMEM_PGOFF_COMPLETION_RING       = 0x180000000
	XDP_UMEM_PGOFF_FILL_RING             = 0x100000000
	XDP_UMEM_REG                         = 0x4
	XDP_ZEROCOPY                         = 0x4
	XENFS_SUPER_MAGIC                    = 0xabba1974
	XFS_SUPER_MAGIC                      = 0x58465342
	XTABS                                = 0x1800
	Z3FOLD_MAGIC                         = 0x33
	ZSMALLOC_MAGIC                       = 0x58295829
)

// Errors
const (
	E2BIG           = syscall.Errno(0x7)
	EACCES          = syscall.Errno(0xd)
	EADDRINUSE      = syscall.Errno(0x62)
	EADDRNOTAVAIL   = syscall.Errno(0x63)
	EADV            = syscall.Errno(0x44)
	EAFNOSUPPORT    = syscall.Errno(0x61)
	EAGAIN          = syscall.Errno(0xb)
	EALREADY        = syscall.Errno(0x72)
	EBADE           = syscall.Errno(0x34)
	EBADF           = syscall.Errno(0x9)
	EBADFD          = syscall.Errno(0x4d)
	EBADMSG         = syscall.Errno(0x4a)
	EBADR           = syscall.Errno(0x35)
	EBADRQC         = syscall.Errno(0x38)
	EBADSLT         = syscall.Errno(0x39)
	EBFONT          = syscall.Errno(0x3b)
	EBUSY           = syscall.Errno(0x10)
	ECANCELED       = syscall.Errno(0x7d)
	ECHILD          = syscall.Errno(0xa)
	ECHRNG          = syscall.Errno(0x2c)
	ECOMM           = syscall.Errno(0x46)
	ECONNABORTED    = syscall.Errno(0x67)
	ECONNREFUSED    = syscall.Errno(0x6f)
	ECONNRESET      = syscall.Errno(0x68)
	EDEADLK         = syscall.Errno(0x23)
	EDEADLOCK       = syscall.Errno(0x23)
	EDESTADDRREQ    = syscall.Errno(0x59)
	EDOM            = syscall.Errno(0x21)
	EDOTDOT         = syscall.Errno(0x49)
	EDQUOT          = syscall.Errno(0x7a)
	EEXIST          = syscall.Errno(0x11)
	EFAULT          = syscall.Errno(0xe)
	EFBIG           = syscall.Errno(0x1b)
	EHOSTDOWN       = syscall.Errno(0x70)
	EHOSTUNREACH    = syscall.Errno(0x71)
	EHWPOISON       = syscall.Errno(0x85)
	EIDRM           = syscall.Errno(0x2b)
	EILSEQ          = syscall.Errno(0x54)
	EINPROGRESS     = syscall.Errno(0x73)
	EINTR           = syscall.Errno(0x4)
	EINVAL          = syscall.Errno(0x16)
	EIO             = syscall.Errno(0x5)
	EISCONN         = syscall.Errno(0x6a)
	EISDIR          = syscall.Errno(0x15)
	EISNAM          = syscall.Errno(0x78)
	EKEYEXPIRED     = syscall.Errno(0x7f)
	EKEYREJECTED    = syscall.Errno(0x81)
	EKEYREVOKED     = syscall.Errno(0x80)
	EL2HLT          = syscall.Errno(0x33)
	EL2NSYNC        = syscall.Errno(0x2d)
	EL3HLT          = syscall.Errno(0x2e)
	EL3RST          = syscall.Errno(0x2f)
	ELIBACC         = syscall.Errno(0x4f)
	ELIBBAD         = syscall.Errno(0x50)
	ELIBEXEC        = syscall.Errno(0x53)
	ELIBMAX         = syscall.Errno(0x52)
	ELIBSCN         = syscall.Errno(0x51)
	ELNRNG          = syscall.Errno(0x30)
	ELOOP           = syscall.Errno(0x28)
	EMEDIUMTYPE     = syscall.Errno(0x7c)
	EMFILE          = syscall.Errno(0x18)
	EMLINK          = syscall.Errno(0x1f)
	EMSGSIZE        = syscall.Errno(0x5a)
	EMULTIHOP       = syscall.Errno(0x48)
	ENAMETOOLONG    = syscall.Errno(0x24)
	ENAVAIL         = syscall.Errno(0x77)
	ENETDOWN        = syscall.Errno(0x64)
	ENETRESET       = syscall.Errno(0x66)
	ENETUNREACH     = syscall.Errno(0x65)
	ENFILE          = syscall.Errno(0x17)
	ENOANO          = syscall.Errno(0x37)
	ENOBUFS         = syscall.Errno(0x69)
	ENOCSI          = syscall.Errno(0x32)
	ENODATA         = syscall.Errno(0x3d)
	ENODEV          = syscall.Errno(0x13)
	ENOENT          = syscall.Errno(0x2)
	ENOEXEC         = syscall.Errno(0x8)
	ENOKEY          = syscall.Errno(0x7e)
	ENOLCK          = syscall.Errno(0x25)
	ENOLINK         = syscall.Errno(0x43)
	ENOMEDIUM       = syscall.Errno(0x7b)
	ENOMEM          = syscall.Errno(0xc)
	ENOMSG          = syscall.Errno(0x2a)
	ENONET          = syscall.Errno(0x40)
	ENOPKG          = syscall.Errno(0x41)
	ENOPROTOOPT     = syscall.Errno(0x5c)
	ENOSPC          = syscall.Errno(0x1c)
	ENOSR           = syscall.Errno(0x3f)
	ENOSTR          = syscall.Errno(0x3c)
	ENOSYS          = syscall.Errno(0x26)
	ENOTBLK         = syscall.Errno(0xf)
	ENOTCONN        = syscall.Errno(0x6b)
	ENOTDIR         = syscall.Errno(0x14)
	ENOTEMPTY       = syscall.Errno(0x27)
	ENOTNAM         = syscall.Errno(0x76)
	ENOTRECOVERABLE = syscall.Errno(0x83)
	ENOTSOCK        = syscall.Errno(0x58)
	ENOTSUP         = syscall.Errno(0x5f)
	ENOTTY          = syscall.Errno(0x19)
	ENOTUNIQ        = syscall.Errno(0x4c)
	ENXIO           = syscall.Errno(0x6)
	EOPNOTSUPP      = syscall.Errno(0x5f)
	EOVERFLOW       = syscall.Errno(0x4b)
	EOWNERDEAD      = syscall.Errno(0x82)
	EPERM           = syscall.Errno(0x1)
	EPFNOSUPPORT    = syscall.Errno(0x60)
	EPIPE           = syscall.Errno(0x20)
	EPROTO          = syscall.Errno(0x47)
	EPROTONOSUPPORT = syscall.Errno(0x5d)
	EPROTOTYPE      = syscall.Errno(0x5b)
	ERANGE          = syscall.Errno(0x22)
	EREMCHG         = syscall.Errno(0x4e)
	EREMOTE         = syscall.Errno(0x42)
	EREMOTEIO       = syscall.Errno(0x79)
	ERESTART        = syscall.Errno(0x55)
	ERFKILL         = syscall.Errno(0x84)
	EROFS           = syscall.Errno(0x1e)
	ESHUTDOWN       = syscall.Errno(0x6c)
	ESOCKTNOSUPPORT = syscall.Errno(0x5e)
	ESPIPE          = syscall.Errno(0x1d)
	ESRCH           = syscall.Errno(0x3)
	ESRMNT          = syscall.Errno(0x45)
	ESTALE          = syscall.Errno(0x74)
	ESTRPIPE        = syscall.Errno(0x56)
	ETIME           = syscall.Errno(0x3e)
	ETIMEDOUT       = syscall.Errno(0x6e)
	ETOOMANYREFS    = syscall.Errno(0x6d)
	ETXTBSY         = syscall.Errno(0x1a)
	EUCLEAN         = syscall.Errno(0x75)
	EUNATCH         = syscall.Errno(0x31)
	EUSERS          = syscall.Errno(0x57)
	EWOULDBLOCK     = syscall.Errno(0xb)
	EXDEV           = syscall.Errno(0x12)
	EXFULL          = syscall.Errno(0x36)
)

// Signals
const (
	SIGABRT   = syscall.Signal(0x6)
	SIGALRM   = syscall.Signal(0xe)
	SIGBUS    = syscall.Signal(0x7)
	SIGCHLD   = syscall.Signal(0x11)
	SIGCLD    = syscall.Signal(0x11)
	SIGCONT   = syscall.Signal(0x12)
	SIGFPE    = syscall.Signal(0x8)
	SIGHUP    = syscall.Signal(0x1)
	SIGILL    = syscall.Signal(0x4)
	SIGINT    = syscall.Signal(0x2)
	SIGIO     = syscall.Signal(0x1d)
	SIGIOT    = syscall.Signal(0x6)
	SIGKILL   = syscall.Signal(0x9)
	SIGPIPE   = syscall.Signal(0xd)
	SIGPOLL   = syscall.Signal(0x1d)
	SIGPROF   = syscall.Signal(0x1b)
	SIGPWR    = syscall.Signal(0x1e)
	SIGQUIT   = syscall.Signal(0x3)
	SIGSEGV   = syscall.Signal(0xb)
	SIGSTKFLT = syscall.Signal(0x10)
	SIGSTOP   = syscall.Signal(0x13)
	SIGSYS    = syscall.Signal(0x1f)
	SIGTERM   = syscall.Signal(0xf)
	SIGTRAP   = syscall.Signal(0x5)
	SIGTSTP   = syscall.Signal(0x14)
	SIGTTIN   = syscall.Signal(0x15)
	SIGTTOU   = syscall.Signal(0x16)
	SIGURG    = syscall.Signal(0x17)
	SIGUSR1   = syscall.Signal(0xa)
	SIGUSR2   = syscall.Signal(0xc)
	SIGVTALRM = syscall.Signal(0x1a)
	SIGWINCH  = syscall.Signal(0x1c)
	SIGXCPU   = syscall.Signal(0x18)
	SIGXFSZ   = syscall.Signal(0x19)
)

// Error table
var errorList = [...]struct {
	num  syscall.Errno
	name string
	desc string
}{
	{1, "EPERM", "operation not permitted"},
	{2, "ENOENT", "no such file or directory"},
	{3, "ESRCH", "no such process"},
	{4, "EINTR", "interrupted system call"},
	{5, "EIO", "input/output error"},
	{6, "ENXIO", "no such device or address"},
	{7, "E2BIG", "argument list too long"},
	{8, "ENOEXEC", "exec format error"},
	{9, "EBADF", "bad file descriptor"},
	{10, "ECHILD", "no child processes"},
	{11, "EAGAIN", "resource temporarily unavailable"},
	{12, "ENOMEM", "cannot allocate memory"},
	{13, "EACCES", "permission denied"},
	{14, "EFAULT", "bad address"},
	{15, "ENOTBLK", "block device required"},
	{16, "EBUSY", "device or resource busy"},
	{17, "EEXIST", "file exists"},
	{18, "EXDEV", "invalid cross-device link"},
	{19, "ENODEV", "no such device"},
	{20, "ENOTDIR", "not a directory"},
	{21, "EISDIR", "is a directory"},
	{22, "EINVAL", "invalid argument"},
	{23, "ENFILE", "too many open files in system"},
	{24, "EMFILE", "too many open files"},
	{25, "ENOTTY", "inappropriate ioctl for device"},
	{26, "ETXTBSY", "text file busy"},
	{27, "EFBIG", "file too large"},
	{28, "ENOSPC", "no space left on device"},
	{29, "ESPIPE", "illegal seek"},
	{30, "EROFS", "read-only file system"},
	{31, "EMLINK", "too many links"},
	{32, "EPIPE", "broken pipe"},
	{33, "EDOM", "numerical argument out of domain"},
	{34, "ERANGE", "numerical result out of range"},
	{35, "EDEADLK", "resource deadlock avoided"},
	{36, "ENAMETOOLONG", "file name too long"},
	{37, "ENOLCK", "no locks available"},
	{38, "ENOSYS", "function not implemented"},
	{39, "ENOTEMPTY", "directory not empty"},
	{40, "ELOOP", "too many levels of symbolic links"},
	{42, "ENOMSG", "no message of desired type"},
	{43, "EIDRM", "identifier removed"},
	{44, "ECHRNG", "channel number out of range"},
	{45, "EL2NSYNC", "level 2 not synchronized"},
	{46, "EL3HLT", "level 3 halted"},
	{47, "EL3RST", "level 3 reset"},
	{48, "ELNRNG", "link number out of range"},
	{49, "EUNATCH", "protocol driver not attached"},
	{50, "ENOCSI", "no CSI structure available"},
	{51, "EL2HLT", "level 2 halted"},
	{52, "EBADE", "invalid exchange"},
	{53, "EBADR", "invalid request descriptor"},
	{54, "EXFULL", "exchange full"},
	{55, "ENOANO", "no anode"},
	{56, "EBADRQC", "invalid request code"},
	{57, "EBADSLT", "invalid slot"},
	{59, "EBFONT", "bad font file format"},
	{60, "ENOSTR", "device not a stream"},
	{61, "ENODATA", "no data available"},
	{62, "ETIME", "timer expired"},
	{63, "ENOSR", "out of streams resources"},
	{64, "ENONET", "machine is not on the network"},
	{65, "ENOPKG", "package not installed"},
	{66, "EREMOTE", "object is remote"},
	{67, "ENOLINK", "link has been severed"},
	{68, "EADV", "advertise error"},
	{69, "ESRMNT", "srmount error"},
	{70, "ECOMM", "communication error on send"},
	{71, "EPROTO", "protocol error"},
	{72, "EMULTIHOP", "multihop attempted"},
	{73, "EDOTDOT", "RFS specific error"},
	{74, "EBADMSG", "bad message"},
	{75, "EOVERFLOW", "value too large for defined data type"},
	{76, "ENOTUNIQ", "name not unique on network"},
	{77, "EBADFD", "file descriptor in bad state"},
	{78, "EREMCHG", "remote address changed"},
	{79, "ELIBACC", "can not access a needed shared library"},
	{80, "ELIBBAD", "accessing a corrupted shared library"},
	{81, "ELIBSCN", ".lib section in a.out corrupted"},
	{82, "ELIBMAX", "attempting to link in too many shared libraries"},
	{83, "ELIBEXEC", "cannot exec a shared library directly"},
	{84, "EILSEQ", "invalid or incomplete multibyte or wide character"},
	{85, "ERESTART", "interrupted system call should be restarted"},
	{86, "ESTRPIPE", "streams pipe error"},
	{87, "EUSERS", "too many users"},
	{88, "ENOTSOCK", "socket operation on non-socket"},
	{89, "EDESTADDRREQ", "destination address required"},
	{90, "EMSGSIZE", "message too long"},
	{91, "EPROTOTYPE", "protocol wrong type for socket"},
	{92, "ENOPROTOOPT", "protocol not available"},
	{93, "EPROTONOSUPPORT", "protocol not supported"},
	{94, "ESOCKTNOSUPPORT", "socket type not supported"},
	{95, "ENOTSUP", "operation not supported"},
	{96, "EPFNOSUPPORT", "protocol family not supported"},
	{97, "EAFNOSUPPORT", "address family not supported by protocol"},
	{98, "EADDRINUSE", "address already in use"},
	{99, "EADDRNOTAVAIL", "cannot assign requested address"},
	{100, "ENETDOWN", "network is down"},
	{101, "ENETUNREACH", "network is unreachable"},
	{102, "ENETRESET", "network dropped connection on reset"},
	{103, "ECONNABORTED", "software caused connection abort"},
	{104, "ECONNRESET", "connection reset by peer"},
	{105, "ENOBUFS", "no buffer space available"},
	{106, "EISCONN", "transport endpoint is already connected"},
	{107, "ENOTCONN", "transport endpoint is not connected"},
	{108, "ESHUTDOWN", "cannot send after transport endpoint shutdown"},
	{109, "ETOOMANYREFS", "too many references: cannot splice"},
	{110, "ETIMEDOUT", "connection timed out"},
	{111, "ECONNREFUSED", "connection refused"},
	{112, "EHOSTDOWN", "host is down"},
	{113, "EHOSTUNREACH", "no route to host"},
	{114, "EALREADY", "operation already in progress"},
	{115, "EINPROGRESS", "operation now in progress"},
	{116, "ESTALE", "stale file handle"},
	{117, "EUCLEAN", "structure needs cleaning"},
	{118, "ENOTNAM", "not a XENIX named type file"},
	{119, "ENAVAIL", "no XENIX semaphores available"},
	{120, "EISNAM", "is a named type file"},
	{121, "EREMOTEIO", "remote I/O error"},
	{122, "EDQUOT", "disk quota exceeded"},
	{123, "ENOMEDIUM", "no medium found"},
	{124, "EMEDIUMTYPE", "wrong medium type"},
	{125, "ECANCELED", "operation canceled"},
	{126, "ENOKEY", "required key not available"},
	{127, "EKEYEXPIRED", "key has expired"},
	{128, "EKEYREVOKED", "key has been revoked"},
	{129, "EKEYREJECTED", "key was rejected by service"},
	{130, "EOWNERDEAD", "owner died"},
	{131, "ENOTRECOVERABLE", "state not recoverable"},
	{132, "ERFKILL", "operation not possible due to RF-kill"},
	{133, "EHWPOISON", "memory page has hardware error"},
}

// Signal table
var signalList = [...]struct {
	num  syscall.Signal
	name string
	desc string
}{
	{1, "SIGHUP", "hangup"},
	{2, "SIGINT", "interrupt"},
	{3, "SIGQUIT", "quit"},
	{4, "SIGILL", "illegal instruction"},
	{5, "SIGTRAP", "trace/breakpoint trap"},
	{6, "SIGABRT", "aborted"},
	{7, "SIGBUS", "bus error"},
	{8, "SIGFPE", "floating point exception"},
	{9, "SIGKILL", "killed"},
	{10, "SIGUSR1", "user defined signal 1"},
	{11, "SIGSEGV", "segmentation fault"},
	{12, "SIGUSR2", "user defined signal 2"},
	{13, "SIGPIPE", "broken pipe"},
	{14, "SIGALRM", "alarm clock"},
	{15, "SIGTERM", "terminated"},
	{16, "SIGSTKFLT", "stack fault"},
	{17, "SIGCHLD", "child exited"},
	{18, "SIGCONT", "continued"},
	{19, "SIGSTOP", "stopped (signal)"},
	{20, "SIGTSTP", "stopped"},
	{21, "SIGTTIN", "stopped (tty input)"},
	{22, "SIGTTOU", "stopped (tty output)"},
	{23, "SIGURG", "urgent I/O condition"},
	{24, "SIGXCPU", "CPU time limit exceeded"},
	{25, "SIGXFSZ", "file size limit exceeded"},
	{26, "SIGVTALRM", "virtual timer expired"},
	{27, "SIGPROF", "profiling timer expired"},
	{28, "SIGWINCH", "window changed"},
	{29, "SIGIO", "I/O possible"},
	{30, "SIGPWR", "power failure"},
	{31, "SIGSYS", "bad system call"},
}
